# ACT I

### SCENE I. London. The palace.
  
_Flourish of trumpets: then hautboys. Enter KING HENRY VI, GLOUCESTER,
SALISBURY, WARWICK, and CARDINAL, on the one side; QUEEN MARGARET, SUFFOLK,
YORK, SOMERSET, and BUCKINGHAM, on the other_

**SUFFOLK**  
As by your high imperial majesty  
I had in charge at my depart for France,  
As procurator to your excellence,  
To marry Princess Margaret for your grace,  
So, in the famous ancient city, Tours,  
In presence of the Kings of France and Sicil,  
The Dukes of Orleans, Calaber, Bretagne and Alencon,  
Seven earls, twelve barons and twenty reverend bishops,  
I have perform'd my task and was espoused:  
And humbly now upon my bended knee,  
In sight of England and her lordly peers,  
Deliver up my title in the queen  
To your most gracious hands, that are the substance  
Of that great shadow I did represent;  
The happiest gift that ever marquess gave,  
The fairest queen that ever king received.  

**KING HENRY VI**  
Suffolk, arise. Welcome, Queen Margaret:  
I can express no kinder sign of love  
Than this kind kiss. O Lord, that lends me life,  
Lend me a heart replete with thankfulness!  
For thou hast given me in this beauteous face  
A world of earthly blessings to my soul,  
If sympathy of love unite our thoughts.  

**QUEEN MARGARET**  
Great King of England and my gracious lord,  
The mutual conference that my mind hath had,  
By day, by night, waking and in my dreams,  
In courtly company or at my beads,  
With you, mine alder-liefest sovereign,  
Makes me the bolder to salute my king  
With ruder terms, such as my wit affords  
And over-joy of heart doth minister.  

**KING HENRY VI**  
Her sight did ravish; but her grace in speech,  
Her words y-clad with wisdom's majesty,  
Makes me from wondering fall to weeping joys;  
Such is the fulness of my heart's content.  
Lords, with one cheerful voice welcome my love.  

**ALL**  
_[Kneeling]_  
Long live Queen Margaret, England's  
happiness!  

**QUEEN MARGARET**  
We thank you all.  

_Flourish_

**SUFFOLK**  
My lord protector, so it please your grace,  
Here are the articles of contracted peace  
Between our sovereign and the French king Charles,  
For eighteen months concluded by consent.  

**GLOUCESTER**  
_[Reads]_  
'Imprimis, it is agreed between the French  
king Charles, and William de la Pole, Marquess of  
Suffolk, ambassador for Henry King of England, that  
the said Henry shall espouse the Lady Margaret,  
daughter unto Reignier King of Naples, Sicilia and  
Jerusalem, and crown her Queen of England ere the  
thirtieth of May next ensuing. Item, that the duchy  
of Anjou and the county of Maine shall be released  
and delivered to the king her father'\--  

_Lets the paper fall_

**KING HENRY VI**  
Uncle, how now!  

**GLOUCESTER**  
Pardon me, gracious lord;  
Some sudden qualm hath struck me at the heart  
And dimm'd mine eyes, that I can read no further.  

**KING HENRY VI**  
Uncle of Winchester, I pray, read on.  

**CARDINAL**  
_[Reads]_  
'Item, It is further agreed between them,  
that the duchies of Anjou and Maine shall be  
released and delivered over to the king her father,  
and she sent over of the King of England's own  
proper cost and charges, without having any dowry.'  

**KING HENRY VI**  
They please us well. Lord marquess, kneel down:  
We here create thee the first duke of Suffolk,  
And gird thee with the sword. Cousin of York,  
We here discharge your grace from being regent  
I' the parts of France, till term of eighteen months  
Be full expired. Thanks, uncle Winchester,  
Gloucester, York, Buckingham, Somerset,  
Salisbury, and Warwick;  
We thank you all for the great favour done,  
In entertainment to my princely queen.  
Come, let us in, and with all speed provide  
To see her coronation be perform'd.  

_Exeunt KING HENRY VI, QUEEN MARGARET, and SUFFOLK_

**GLOUCESTER**  
Brave peers of England, pillars of the state,  
To you Duke Humphrey must unload his grief,  
Your grief, the common grief of all the land.  
What! did my brother Henry spend his youth,  
His valour, coin and people, in the wars?  
Did he so often lodge in open field,  
In winter's cold and summer's parching heat,  
To conquer France, his true inheritance?  
And did my brother Bedford toil his wits,  
To keep by policy what Henry got?  
Have you yourselves, Somerset, Buckingham,  
Brave York, Salisbury, and victorious Warwick,  
Received deep scars in France and Normandy?  
Or hath mine uncle Beaufort and myself,  
With all the learned council of the realm,  
Studied so long, sat in the council-house  
Early and late, debating to and fro  
How France and Frenchmen might be kept in awe,  
And had his highness in his infancy  
Crowned in Paris in despite of foes?  
And shall these labours and these honours die?  
Shall Henry's conquest, Bedford's vigilance,  
Your deeds of war and all our counsel die?  
O peers of England, shameful is this league!  
Fatal this marriage, cancelling your fame,  
Blotting your names from books of memory,  
Razing the characters of your renown,  
Defacing monuments of conquer'd France,  
Undoing all, as all had never been!  

**CARDINAL**  
Nephew, what means this passionate discourse,  
This peroration with such circumstance?  
For France, 'tis ours; and we will keep it still.  

**GLOUCESTER**  
Ay, uncle, we will keep it, if we can;  
But now it is impossible we should:  
Suffolk, the new-made duke that rules the roast,  
Hath given the duchy of Anjou and Maine  
Unto the poor King Reignier, whose large style  
Agrees not with the leanness of his purse.  

**SALISBURY**  
Now, by the death of Him that died for all,  
These counties were the keys of Normandy.  
But wherefore weeps Warwick, my valiant son?  

**WARWICK**  
For grief that they are past recovery:  
For, were there hope to conquer them again,  
My sword should shed hot blood, mine eyes no tears.  
Anjou and Maine! myself did win them both;  
Those provinces these arms of mine did conquer:  
And are the cities, that I got with wounds,  
Delivered up again with peaceful words?  
Mort Dieu!  

**YORK**  
For Suffolk's duke, may he be suffocate,  
That dims the honour of this warlike isle!  
France should have torn and rent my very heart,  
Before I would have yielded to this league.  
I never read but England's kings have had  
Large sums of gold and dowries with their wives:  
And our King Henry gives away his own,  
To match with her that brings no vantages.  

**GLOUCESTER**  
A proper jest, and never heard before,  
That Suffolk should demand a whole fifteenth  
For costs and charges in transporting her!  
She should have stayed in France and starved  
in France, Before--  

**CARDINAL**  
My Lord of Gloucester, now ye grow too hot:  
It was the pleasure of my lord the King.  

**GLOUCESTER**  
My Lord of Winchester, I know your mind;  
'Tis not my speeches that you do mislike,  
But 'tis my presence that doth trouble ye.  
Rancour will out: proud prelate, in thy face  
I see thy fury: if I longer stay,  
We shall begin our ancient bickerings.  
Lordings, farewell; and say, when I am gone,  
I prophesied France will be lost ere long.  

_Exit_

**CARDINAL**  
So, there goes our protector in a rage.  
'Tis known to you he is mine enemy,  
Nay, more, an enemy unto you all,  
And no great friend, I fear me, to the king.  
Consider, lords, he is the next of blood,  
And heir apparent to the English crown:  
Had Henry got an empire by his marriage,  
And all the wealthy kingdoms of the west,  
There's reason he should be displeased at it.  
Look to it, lords! let not his smoothing words  
Bewitch your hearts; be wise and circumspect.  
What though the common people favour him,  
Calling him 'Humphrey, the good Duke of  
Gloucester,'  
Clapping their hands, and crying with loud voice,  
'Jesu maintain your royal excellence!'  
With 'God preserve the good Duke Humphrey!'  
I fear me, lords, for all this flattering gloss,  
He will be found a dangerous protector.  

**BUCKINGHAM**  
Why should he, then, protect our sovereign,  
He being of age to govern of himself?  
Cousin of Somerset, join you with me,  
And all together, with the Duke of Suffolk,  
We'll quickly hoise Duke Humphrey from his seat.  

**CARDINAL**  
This weighty business will not brook delay:  
I'll to the Duke of Suffolk presently.  

_Exit_

**SOMERSET**  
Cousin of Buckingham, though Humphrey's pride  
And greatness of his place be grief to us,  
Yet let us watch the haughty cardinal:  
His insolence is more intolerable  
Than all the princes in the land beside:  
If Gloucester be displaced, he'll be protector.  

**BUCKINGHAM**  
Or thou or I, Somerset, will be protector,  
Despite Duke Humphrey or the cardinal.  

_Exeunt BUCKINGHAM and SOMERSET_

**SALISBURY**  
Pride went before, ambition follows him.  
While these do labour for their own preferment,  
Behoves it us to labour for the realm.  
I never saw but Humphrey Duke of Gloucester  
Did bear him like a noble gentleman.  
Oft have I seen the haughty cardinal,  
More like a soldier than a man o' the church,  
As stout and proud as he were lord of all,  
Swear like a ruffian and demean himself  
Unlike the ruler of a commonweal.  
Warwick, my son, the comfort of my age,  
Thy deeds, thy plainness and thy housekeeping,  
Hath won the greatest favour of the commons,  
Excepting none but good Duke Humphrey:  
And, brother York, thy acts in Ireland,  
In bringing them to civil discipline,  
Thy late exploits done in the heart of France,  
When thou wert regent for our sovereign,  
Have made thee fear'd and honour'd of the people:  
Join we together, for the public good,  
In what we can, to bridle and suppress  
The pride of Suffolk and the cardinal,  
With Somerset's and Buckingham's ambition;  
And, as we may, cherish Duke Humphrey's deeds,  
While they do tend the profit of the land.  

**WARWICK**  
So God help Warwick, as he loves the land,  
And common profit of his country!  

**YORK**  
_[Aside]_  
And so says York, for he hath greatest cause.  

**SALISBURY**  
Then let's make haste away, and look unto the main.  

**WARWICK**  
Unto the main! O father, Maine is lost;  
That Maine which by main force Warwick did win,  
And would have kept so long as breath did last!  
Main chance, father, you meant; but I meant Maine,  
Which I will win from France, or else be slain,  

_Exeunt WARWICK and SALISBURY_

**YORK**  
Anjou and Maine are given to the French;  
Paris is lost; the state of Normandy  
Stands on a tickle point, now they are gone:  
Suffolk concluded on the articles,  
The peers agreed, and Henry was well pleased  
To change two dukedoms for a duke's fair daughter.  
I cannot blame them all: what is't to them?  
'Tis thine they give away, and not their own.  
Pirates may make cheap pennyworths of their pillage  
And purchase friends and give to courtezans,  
Still revelling like lords till all be gone;  
While as the silly owner of the goods  
Weeps over them and wrings his hapless hands  
And shakes his head and trembling stands aloof,  
While all is shared and all is borne away,  
Ready to starve and dare not touch his own:  
So York must sit and fret and bite his tongue,  
While his own lands are bargain'd for and sold.  
Methinks the realms of England, France and Ireland  
Bear that proportion to my flesh and blood  
As did the fatal brand Althaea burn'd  
Unto the prince's heart of Calydon.  
Anjou and Maine both given unto the French!  
Cold news for me, for I had hope of France,  
Even as I have of fertile England's soil.  
A day will come when York shall claim his own;  
And therefore I will take the Nevils' parts  
And make a show of love to proud Duke Humphrey,  
And, when I spy advantage, claim the crown,  
For that's the golden mark I seek to hit:  
Nor shall proud Lancaster usurp my right,  
Nor hold the sceptre in his childish fist,  
Nor wear the diadem upon his head,  
Whose church-like humours fits not for a crown.  
Then, York, be still awhile, till time do serve:  
Watch thou and wake when others be asleep,  
To pry into the secrets of the state;  
Till Henry, surfeiting in joys of love,  
With his new bride and England's dear-bought queen,  
And Humphrey with the peers be fall'n at jars:  
Then will I raise aloft the milk-white rose,  
With whose sweet smell the air shall be perfumed;  
And in my standard bear the arms of York  
To grapple with the house of Lancaster;  
And, force perforce, I'll make him yield the crown,  
Whose bookish rule hath pull'd fair England down.  

_Exit_

### SCENE II. GLOUCESTER'S house.

_Enter GLOUCESTER and his DUCHESS_

**DUCHESS**  
Why droops my lord, like over-ripen'd corn,  
Hanging the head at Ceres' plenteous load?  
Why doth the great Duke Humphrey knit his brows,  
As frowning at the favours of the world?  
Why are thine eyes fixed to the sullen earth,  
Gazing on that which seems to dim thy sight?  
What seest thou there? King Henry's diadem,  
Enchased with all the honours of the world?  
If so, gaze on, and grovel on thy face,  
Until thy head be circled with the same.  
Put forth thy hand, reach at the glorious gold.  
What, is't too short? I'll lengthen it with mine:  
And, having both together heaved it up,  
We'll both together lift our heads to heaven,  
And never more abase our sight so low  
As to vouchsafe one glance unto the ground.  

**GLOUCESTER**  
O Nell, sweet Nell, if thou dost love thy lord,  
Banish the canker of ambitious thoughts.  
And may that thought, when I imagine ill  
Against my king and nephew, virtuous Henry,  
Be my last breathing in this mortal world!  
My troublous dream this night doth make me sad.  

**DUCHESS**  
What dream'd my lord? tell me, and I'll requite it  
With sweet rehearsal of my morning's dream.  

**GLOUCESTER**  
Methought this staff, mine office-badge in court,  
Was broke in twain; by whom I have forgot,  
But, as I think, it was by the cardinal;  
And on the pieces of the broken wand  
Were placed the heads of Edmund Duke of Somerset,  
And William de la Pole, first duke of Suffolk.  
This was my dream: what it doth bode, God knows.  

**DUCHESS**  
Tut, this was nothing but an argument  
That he that breaks a stick of Gloucester's grove  
Shall lose his head for his presumption.  
But list to me, my Humphrey, my sweet duke:  
Methought I sat in seat of majesty  
In the cathedral church of Westminster,  
And in that chair where kings and queens are crown'd;  
Where Henry and dame Margaret kneel'd to me  
And on my head did set the diadem.  

**GLOUCESTER**  
Nay, Eleanor, then must I chide outright:  
Presumptuous dame, ill-nurtured Eleanor,  
Art thou not second woman in the realm,  
And the protector's wife, beloved of him?  
Hast thou not worldly pleasure at command,  
Above the reach or compass of thy thought?  
And wilt thou still be hammering treachery,  
To tumble down thy husband and thyself  
From top of honour to disgrace's feet?  
Away from me, and let me hear no more!  

**DUCHESS**  
What, what, my lord! are you so choleric  
With Eleanor, for telling but her dream?  
Next time I'll keep my dreams unto myself,  
And not be cheque'd.  

**GLOUCESTER**  
Nay, be not angry; I am pleased again.  

_Enter Messenger_

**Messenger**  
My lord protector, 'tis his highness' pleasure  
You do prepare to ride unto Saint Alban's,  
Where as the king and queen do mean to hawk.  

**GLOUCESTER**  
I go. Come, Nell, thou wilt ride with us?  

**DUCHESS**  
Yes, my good lord, I'll follow presently.  

_Exeunt GLOUCESTER and Messenger_

Follow I must; I cannot go before,  
While Gloucester bears this base and humble mind.  
Were I a man, a duke, and next of blood,  
I would remove these tedious stumbling-blocks  
And smooth my way upon their headless necks;  
And, being a woman, I will not be slack  
To play my part in Fortune's pageant.  
Where are you there? Sir John! nay, fear not, man,  
We are alone; here's none but thee and I.  

_Enter HUME_

**HUME**  
Jesus preserve your royal majesty!  

**DUCHESS**  
What say'st thou? majesty! I am but grace.  

**HUME**  
But, by the grace of God, and Hume's advice,  
Your grace's title shall be multiplied.  

**DUCHESS**  
What say'st thou, man? hast thou as yet conferr'd  
With Margery Jourdain, the cunning witch,  
With Roger Bolingbroke, the conjurer?  
And will they undertake to do me good?  

**HUME**  
This they have promised, to show your highness  
A spirit raised from depth of under-ground,  
That shall make answer to such questions  
As by your grace shall be propounded him.  

**DUCHESS**  
It is enough; I'll think upon the questions:  
When from St. Alban's we do make return,  
We'll see these things effected to the full.  
Here, Hume, take this reward; make merry, man,  
With thy confederates in this weighty cause.  

_Exit_

**HUME**  
Hume must make merry with the duchess' gold;  
Marry, and shall. But how now, Sir John Hume!  
Seal up your lips, and give no words but mum:  
The business asketh silent secrecy.  
Dame Eleanor gives gold to bring the witch:  
Gold cannot come amiss, were she a devil.  
Yet have I gold flies from another coast;  
I dare not say, from the rich cardinal  
And from the great and new-made Duke of Suffolk,  
Yet I do find it so; for to be plain,  
They, knowing Dame Eleanor's aspiring humour,  
Have hired me to undermine the duchess  
And buz these conjurations in her brain.  
They say 'A crafty knave does need no broker;'  
Yet am I Suffolk and the cardinal's broker.  
Hume, if you take not heed, you shall go near  
To call them both a pair of crafty knaves.  
Well, so it stands; and thus, I fear, at last  
Hume's knavery will be the duchess' wreck,  
And her attainture will be Humphrey's fall:  
Sort how it will, I shall have gold for all.  

_Exit_

### SCENE III. The palace.

_Enter three or four Petitioners, PETER, the Armourer 's man, being one_

**First Petitioner**  
My masters, let's stand close: my lord protector  
will come this way by and by, and then we may deliver  
our supplications in the quill.  

**Second Petitioner**  
Marry, the Lord protect him, for he's a good man!  
Jesu bless him!  

_Enter SUFFOLK and QUEEN MARGARET_

**PETER**  
Here a' comes, methinks, and the queen with him.  
I'll be the first, sure.  

**Second Petitioner**  
Come back, fool; this is the Duke of Suffolk, and  
not my lord protector.  

**SUFFOLK**  
How now, fellow! would'st anything with me?  

**First Petitioner**  
I pray, my lord, pardon me; I took ye for my lord  
protector.  

**QUEEN MARGARET**  
_[Reading]_  
'To my Lord Protector!' Are your  
supplications to his lordship? Let me see them:  
what is thine?  

**First Petitioner**  
Mine is, an't please your grace, against John  
Goodman, my lord cardinal's man, for keeping my  
house, and lands, and wife and all, from me.  

**SUFFOLK**  
Thy wife, too! that's some wrong, indeed. What's  
yours? What's here!  

_Reads_

'Against the Duke of Suffolk, for enclosing the  
commons of Melford.' How now, sir knave!  

**Second Petitioner**  
Alas, sir, I am but a poor petitioner of our whole township.  

**PETER**  
_[Giving his petition]_  
Against my master, Thomas  
Horner, for saying that the Duke of York was rightful  
heir to the crown.  

**QUEEN MARGARET**  
What sayst thou? did the Duke of York say he was  
rightful heir to the crown?  

**PETER**  
That my master was? no, forsooth: my master said  
that he was, and that the king was an usurper.  

**SUFFOLK**  
Who is there?  

_Enter Servant_

Take this fellow in, and send for  
his master with a pursuivant presently: we'll hear  
more of your matter before the King.  

_Exit Servant with PETER_

**QUEEN MARGARET**  
And as for you, that love to be protected  
Under the wings of our protector's grace,  
Begin your suits anew, and sue to him.  

_Tears the supplication_

Away, base cullions! Suffolk, let them go.  

**ALL**  
Come, let's be gone.  

_Exeunt_

**QUEEN MARGARET**  
My Lord of Suffolk, say, is this the guise,  
Is this the fashion in the court of England?  
Is this the government of Britain's isle,  
And this the royalty of Albion's king?  
What shall King Henry be a pupil still  
Under the surly Gloucester's governance?  
Am I a queen in title and in style,  
And must be made a subject to a duke?  
I tell thee, Pole, when in the city Tours  
Thou ran'st a tilt in honour of my love  
And stolest away the ladies' hearts of France,  
I thought King Henry had resembled thee  
In courage, courtship and proportion:  
But all his mind is bent to holiness,  
To number Ave-Maries on his beads;  
His champions are the prophets and apostles,  
His weapons holy saws of sacred writ,  
His study is his tilt-yard, and his loves  
Are brazen images of canonized saints.  
I would the college of the cardinals  
Would choose him pope, and carry him to Rome,  
And set the triple crown upon his head:  
That were a state fit for his holiness.  

**SUFFOLK**  
Madam, be patient: as I was cause  
Your highness came to England, so will I  
In England work your grace's full content.  

**QUEEN MARGARET**  
Beside the haughty protector, have we Beaufort,  
The imperious churchman, Somerset, Buckingham,  
And grumbling York: and not the least of these  
But can do more in England than the king.  

**SUFFOLK**  
And he of these that can do most of all  
Cannot do more in England than the Nevils:  
Salisbury and Warwick are no simple peers.  

**QUEEN MARGARET**  
Not all these lords do vex me half so much  
As that proud dame, the lord protector's wife.  
She sweeps it through the court with troops of ladies,  
More like an empress than Duke Humphrey's wife:  
Strangers in court do take her for the queen:  
She bears a duke's revenues on her back,  
And in her heart she scorns our poverty:  
Shall I not live to be avenged on her?  
Contemptuous base-born callet as she is,  
She vaunted 'mongst her minions t'other day,  
The very train of her worst wearing gown  
Was better worth than all my father's lands,  
Till Suffolk gave two dukedoms for his daughter.  

**SUFFOLK**  
Madam, myself have limed a bush for her,  
And placed a quire of such enticing birds,  
That she will light to listen to the lays,  
And never mount to trouble you again.  
So, let her rest: and, madam, list to me;  
For I am bold to counsel you in this.  
Although we fancy not the cardinal,  
Yet must we join with him and with the lords,  
Till we have brought Duke Humphrey in disgrace.  
As for the Duke of York, this late complaint  
Will make but little for his benefit.  
So, one by one, we'll weed them all at last,  
And you yourself shall steer the happy helm.  

_Sound a sennet. Enter KING HENRY VI, GLOUCESTER, CARDINAL, BUCKINGHAM,
YORK, SOMERSET, SALISBURY, WARWICK, and the DUCHESS_

**KING HENRY VI**  
For my part, noble lords, I care not which;  
Or Somerset or York, all's one to me.  

**YORK**  
If York have ill demean'd himself in France,  
Then let him be denay'd the regentship.  

**SOMERSET**  
If Somerset be unworthy of the place,  
Let York be regent; I will yield to him.  

**WARWICK**  
Whether your grace be worthy, yea or no,  
Dispute not that: York is the worthier.  

**CARDINAL**  
Ambitious Warwick, let thy betters speak.  

**WARWICK**  
The cardinal's not my better in the field.  

**BUCKINGHAM**  
All in this presence are thy betters, Warwick.  

**WARWICK**  
Warwick may live to be the best of all.  

**SALISBURY**  
Peace, son! and show some reason, Buckingham,  
Why Somerset should be preferred in this.  

**QUEEN MARGARET**  
Because the king, forsooth, will have it so.  

**GLOUCESTER**  
Madam, the king is old enough himself  
To give his censure: these are no women's matters.  

**QUEEN MARGARET**  
If he be old enough, what needs your grace  
To be protector of his excellence?  

**GLOUCESTER**  
Madam, I am protector of the realm;  
And, at his pleasure, will resign my place.  

**SUFFOLK**  
Resign it then and leave thine insolence.  
Since thou wert king--as who is king but thou?--  
The commonwealth hath daily run to wreck;  
The Dauphin hath prevail'd beyond the seas;  
And all the peers and nobles of the realm  
Have been as bondmen to thy sovereignty.  

**CARDINAL**  
The commons hast thou rack'd; the clergy's bags  
Are lank and lean with thy extortions.  

**SOMERSET**  
Thy sumptuous buildings and thy wife's attire  
Have cost a mass of public treasury.  

**BUCKINGHAM**  
Thy cruelty in execution  
Upon offenders, hath exceeded law,  
And left thee to the mercy of the law.  

**QUEEN MARGARET**  
They sale of offices and towns in France,  
If they were known, as the suspect is great,  
Would make thee quickly hop without thy head.  

_Exit GLOUCESTER. QUEEN MARGARET drops her fan_

Give me my fan: what, minion! can ye not?  

_She gives the DUCHESS a box on the ear_

I cry you mercy, madam; was it you?  

**DUCHESS**  
Was't I! yea, I it was, proud Frenchwoman:  
Could I come near your beauty with my nails,  
I'd set my ten commandments in your face.  

**KING HENRY VI**  
Sweet aunt, be quiet; 'twas against her will.  

**DUCHESS**  
Against her will! good king, look to't in time;  
She'll hamper thee, and dandle thee like a baby:  
Though in this place most master wear no breeches,  
She shall not strike Dame Eleanor unrevenged.  

_Exit_

**BUCKINGHAM**  
Lord cardinal, I will follow Eleanor,  
And listen after Humphrey, how he proceeds:  
She's tickled now; her fume needs no spurs,  
She'll gallop far enough to her destruction.  

_Exit_

_Re-enter GLOUCESTER_

**GLOUCESTER**  
Now, lords, my choler being over-blown  
With walking once about the quadrangle,  
I come to talk of commonwealth affairs.  
As for your spiteful false objections,  
Prove them, and I lie open to the law:  
But God in mercy so deal with my soul,  
As I in duty love my king and country!  
But, to the matter that we have in hand:  
I say, my sovereign, York is meetest man  
To be your regent in the realm of France.  

**SUFFOLK**  
Before we make election, give me leave  
To show some reason, of no little force,  
That York is most unmeet of any man.  

**YORK**  
I'll tell thee, Suffolk, why I am unmeet:  
First, for I cannot flatter thee in pride;  
Next, if I be appointed for the place,  
My Lord of Somerset will keep me here,  
Without discharge, money, or furniture,  
Till France be won into the Dauphin's hands:  
Last time, I danced attendance on his will  
Till Paris was besieged, famish'd, and lost.  

**WARWICK**  
That can I witness; and a fouler fact  
Did never traitor in the land commit.  

**SUFFOLK**  
Peace, headstrong Warwick!  

**WARWICK**  
Image of pride, why should I hold my peace?  

_Enter HORNER, the Armourer, and his man PETER, guarded_

**SUFFOLK**  
Because here is a man accused of treason:  
Pray God the Duke of York excuse himself!  

**YORK**  
Doth any one accuse York for a traitor?  

**KING HENRY VI**  
What mean'st thou, Suffolk; tell me, what are these?  

**SUFFOLK**  
Please it your majesty, this is the man  
That doth accuse his master of high treason:  
His words were these: that Richard, Duke of York,  
Was rightful heir unto the English crown  
And that your majesty was a usurper.  

**KING HENRY VI**  
Say, man, were these thy words?  

**HORNER**  
An't shall please your majesty, I never said nor  
thought any such matter: God is my witness, I am  
falsely accused by the villain.  

**PETER**  
By these ten bones, my lords, he did speak them to  
me in the garret one night, as we were scouring my  
Lord of York's armour.  

**YORK**  
Base dunghill villain and mechanical,  
I'll have thy head for this thy traitor's speech.  
I do beseech your royal majesty,  
Let him have all the rigor of the law.  

**HORNER**  
Alas, my lord, hang me, if ever I spake the words.  
My accuser is my 'prentice; and when I did correct  
him for his fault the other day, he did vow upon his  
knees he would be even with me: I have good  
witness of this: therefore I beseech your majesty,  
do not cast away an honest man for a villain's  
accusation.  

**KING HENRY VI**  
Uncle, what shall we say to this in law?  

**GLOUCESTER**  
This doom, my lord, if I may judge:  
Let Somerset be regent over the French,  
Because in York this breeds suspicion:  
And let these have a day appointed them  
For single combat in convenient place,  
For he hath witness of his servant's malice:  
This is the law, and this Duke Humphrey's doom.  

**SOMERSET**  
I humbly thank your royal majesty.  

**HORNER**  
And I accept the combat willingly.  

**PETER**  
Alas, my lord, I cannot fight; for God's sake, pity  
my case. The spite of man prevaileth against me. O  
Lord, have mercy upon me! I shall never be able to  
fight a blow. O Lord, my heart!  

**GLOUCESTER**  
Sirrah, or you must fight, or else be hang'd.  

**KING HENRY VI**  
Away with them to prison; and the day of combat  
shall be the last of the next month. Come,  
Somerset, we'll see thee sent away.  

_Flourish. Exeunt_

### SCENE IV. GLOUCESTER's garden.

_Enter MARGARET JOURDAIN, HUME, SOUTHWELL, and BOLINGBROKE_

**HUME**  
Come, my masters; the duchess, I tell you, expects  
performance of your promises.  

**BOLINGBROKE**  
Master Hume, we are therefore provided: will her  
ladyship behold and hear our exorcisms?  

**HUME**  
Ay, what else? fear you not her courage.  

**BOLINGBROKE**  
I have heard her reported to be a woman of an  
invincible spirit: but it shall be convenient,  
Master Hume, that you be by her aloft, while we be  
busy below; and so, I pray you, go, in God's name,  
and leave us.  

_Exit HUME_

Mother Jourdain, be you  
prostrate and grovel on the earth; John Southwell,  
read you; and let us to our work.  

_Enter the DUCHESS aloft, HUME following_

**DUCHESS**  
Well said, my masters; and welcome all. To this  
gear the sooner the better.  

**BOLINGBROKE**  
Patience, good lady; wizards know their times:  
Deep night, dark night, the silent of the night,  
The time of night when Troy was set on fire;  
The time when screech-owls cry and ban-dogs howl,  
And spirits walk and ghosts break up their graves,  
That time best fits the work we have in hand.  
Madam, sit you and fear not: whom we raise,  
We will make fast within a hallow'd verge.  

_Here they do the ceremonies belonging, and make the circle; BOLINGBROKE or
SOUTHWELL reads, Conjuro te, & c. It thunders and lightens terribly; then the
Spirit riseth_

**Spirit**  
Adsum.  

**MARGARET JOURDAIN**  
Asmath,  
By the eternal God, whose name and power  
Thou tremblest at, answer that I shall ask;  
For, till thou speak, thou shalt not pass from hence.  

**Spirit**  
Ask what thou wilt. That I had said and done!  

**BOLINGBROKE**  
'First of the king: what shall of him become?'  

_Reading out of a paper_

**Spirit**  
The duke yet lives that Henry shall depose;  
But him outlive, and die a violent death.  

_As the Spirit speaks, SOUTHWELL writes the answer_

**BOLINGBROKE**  
'What fates await the Duke of Suffolk?'  

**Spirit**  
By water shall he die, and take his end.  

**BOLINGBROKE**  
'What shall befall the Duke of Somerset?'  

**Spirit**  
Let him shun castles;  
Safer shall he be upon the sandy plains  
Than where castles mounted stand.  
Have done, for more I hardly can endure.  

**BOLINGBROKE**  
Descend to darkness and the burning lake!  
False fiend, avoid!  

_Thunder and lightning. Exit Spirit_

_Enter YORK and BUCKINGHAM with their Guard and break in_

**YORK**  
Lay hands upon these traitors and their trash.  
Beldam, I think we watch'd you at an inch.  
What, madam, are you there? the king and commonweal  
Are deeply indebted for this piece of pains:  
My lord protector will, I doubt it not,  
See you well guerdon'd for these good deserts.  

**DUCHESS**  
Not half so bad as thine to England's king,  
Injurious duke, that threatest where's no cause.  

**BUCKINGHAM**  
True, madam, none at all: what call you this?  
Away with them! let them be clapp'd up close.  
And kept asunder. You, madam, shall with us.  
Stafford, take her to thee.  

_Exeunt above DUCHESS and HUME, guarded_

We'll see your trinkets here all forthcoming.  
All, away!  

_Exeunt guard with MARGARET JOURDAIN, SOUTHWELL, & c_

**YORK**  
Lord Buckingham, methinks, you watch'd her well:  
A pretty plot, well chosen to build upon!  
Now, pray, my lord, let's see the devil's writ.  
What have we here?  

_Reads_

'The duke yet lives, that Henry shall depose;  
But him outlive, and die a violent death.'  
Why, this is just  
'Aio te, AEacida, Romanos vincere posse.'  
Well, to the rest:  
'Tell me what fate awaits the Duke of Suffolk?  
By water shall he die, and take his end.  
What shall betide the Duke of Somerset?  
Let him shun castles;  
Safer shall he be upon the sandy plains  
Than where castles mounted stand.'  
Come, come, my lords;  
These oracles are hardly attain'd,  
And hardly understood.  
The king is now in progress towards Saint Alban's,  
With him the husband of this lovely lady:  
Thither go these news, as fast as horse can  
carry them:  
A sorry breakfast for my lord protector.  

**BUCKINGHAM**  
Your grace shall give me leave, my Lord of York,  
To be the post, in hope of his reward.  

**YORK**  
At your pleasure, my good lord. Who's within  
there, ho!  

_Enter a Servingman_

Invite my Lords of Salisbury and Warwick  
To sup with me to-morrow night. Away!  

_Exeunt_

# ACT II

### SCENE I. Saint Alban's.

_Enter KING HENRY VI, QUEEN MARGARET, GLOUCESTER, CARDINAL, and SUFFOLK,
with Falconers halloing_

**QUEEN MARGARET**  
Believe me, lords, for flying at the brook,  
I saw not better sport these seven years' day:  
Yet, by your leave, the wind was very high;  
And, ten to one, old Joan had not gone out.  

**KING HENRY VI**  
But what a point, my lord, your falcon made,  
And what a pitch she flew above the rest!  
To see how God in all his creatures works!  
Yea, man and birds are fain of climbing high.  

**SUFFOLK**  
No marvel, an it like your majesty,  
My lord protector's hawks do tower so well;  
They know their master loves to be aloft,  
And bears his thoughts above his falcon's pitch.  

**GLOUCESTER**  
My lord, 'tis but a base ignoble mind  
That mounts no higher than a bird can soar.  

**CARDINAL**  
I thought as much; he would be above the clouds.  

**GLOUCESTER**  
Ay, my lord cardinal? how think you by that?  
Were it not good your grace could fly to heaven?  

**KING HENRY VI**  
The treasury of everlasting joy.  

**CARDINAL**  
Thy heaven is on earth; thine eyes and thoughts  
Beat on a crown, the treasure of thy heart;  
Pernicious protector, dangerous peer,  
That smooth'st it so with king and commonweal!  

**GLOUCESTER**  
What, cardinal, is your priesthood grown peremptory?  
Tantaene animis coelestibus irae?  
Churchmen so hot? good uncle, hide such malice;  
With such holiness can you do it?  

**SUFFOLK**  
No malice, sir; no more than well becomes  
So good a quarrel and so bad a peer.  

**GLOUCESTER**  
As who, my lord?  

**SUFFOLK**  
Why, as you, my lord,  
An't like your lordly lord-protectorship.  

**GLOUCESTER**  
Why, Suffolk, England knows thine insolence.  

**QUEEN MARGARET**  
And thy ambition, Gloucester.  

**KING HENRY VI**  
I prithee, peace, good queen,  
And whet not on these furious peers;  
For blessed are the peacemakers on earth.  

**CARDINAL**  
Let me be blessed for the peace I make,  
Against this proud protector, with my sword!  

**GLOUCESTER**  
_[Aside to CARDINAL]_  
Faith, holy uncle, would  
'twere come to that!  

**CARDINAL**  
_[Aside to GLOUCESTER]_  
Marry, when thou darest.  

**GLOUCESTER**  
_[Aside to CARDINAL]_  
Make up no factious  
numbers for the matter;  
In thine own person answer thy abuse.  

**CARDINAL**  
_[Aside to GLOUCESTER]_  
Ay, where thou darest  
not peep: an if thou darest,  
This evening, on the east side of the grove.  

**KING HENRY VI**  
How now, my lords!  

**CARDINAL**  
Believe me, cousin Gloucester,  
Had not your man put up the fowl so suddenly,  
We had had more sport.  

_Aside to GLOUCESTER_

Come with thy two-hand sword.  

**GLOUCESTER**  
True, uncle.  

**CARDINAL**  
_[Aside to GLOUCESTER]_  
Are ye advised? the  
east side of the grove?  

**GLOUCESTER**  
_[Aside to CARDINAL]_  
Cardinal, I am with you.  

**KING HENRY VI**  
Why, how now, uncle Gloucester!  

**GLOUCESTER**  
Talking of hawking; nothing else, my lord.  

_Aside to CARDINAL_

Now, by God's mother, priest, I'll shave your crown for this,  
Or all my fence shall fail.  

**CARDINAL**  
_[Aside to GLOUCESTER]_  
Medice, teipsum--  
Protector, see to't well, protect yourself.  

**KING HENRY VI**  
The winds grow high; so do your stomachs, lords.  
How irksome is this music to my heart!  
When such strings jar, what hope of harmony?  
I pray, my lords, let me compound this strife.  

_Enter a Townsman of Saint Alban 's, crying 'A miracle!'_

**GLOUCESTER**  
What means this noise?  
Fellow, what miracle dost thou proclaim?  

**Townsman**  
A miracle! a miracle!  

**SUFFOLK**  
Come to the king and tell him what miracle.  

**Townsman**  
Forsooth, a blind man at Saint Alban's shrine,  
Within this half-hour, hath received his sight;  
A man that ne'er saw in his life before.  

**KING HENRY VI**  
Now, God be praised, that to believing souls  
Gives light in darkness, comfort in despair!  

_Enter the Mayor of Saint Alban 's and his brethren, bearing SIMPCOX,
between two in a chair, SIMPCOX's Wife following_

**CARDINAL**  
Here comes the townsmen on procession,  
To present your highness with the man.  

**KING HENRY VI**  
Great is his comfort in this earthly vale,  
Although by his sight his sin be multiplied.  

**GLOUCESTER**  
Stand by, my masters: bring him near the king;  
His highness' pleasure is to talk with him.  

**KING HENRY VI**  
Good fellow, tell us here the circumstance,  
That we for thee may glorify the Lord.  
What, hast thou been long blind and now restored?  

**SIMPCOX**  
Born blind, an't please your grace.  

**Wife**  
Ay, indeed, was he.  

**SUFFOLK**  
What woman is this?  

**Wife**  
His wife, an't like your worship.  

**GLOUCESTER**  
Hadst thou been his mother, thou couldst have  
better told.  

**KING HENRY VI**  
Where wert thou born?  

**SIMPCOX**  
At Berwick in the north, an't like your grace.  

**KING HENRY VI**  
Poor soul, God's goodness hath been great to thee:  
Let never day nor night unhallow'd pass,  
But still remember what the Lord hath done.  

**QUEEN MARGARET**  
Tell me, good fellow, camest thou here by chance,  
Or of devotion, to this holy shrine?  

**SIMPCOX**  
God knows, of pure devotion; being call'd  
A hundred times and oftener, in my sleep,  
By good Saint Alban; who said, 'Simpcox, come,  
Come, offer at my shrine, and I will help thee.'  

**Wife**  
Most true, forsooth; and many time and oft  
Myself have heard a voice to call him so.  

**CARDINAL**  
What, art thou lame?  

**SIMPCOX**  
Ay, God Almighty help me!  

**SUFFOLK**  
How camest thou so?  

**SIMPCOX**  
A fall off of a tree.  

**Wife**  
A plum-tree, master.  

**GLOUCESTER**  
How long hast thou been blind?  

**SIMPCOX**  
Born so, master.  

**GLOUCESTER**  
What, and wouldst climb a tree?  

**SIMPCOX**  
But that in all my life, when I was a youth.  

**Wife**  
Too true; and bought his climbing very dear.  

**GLOUCESTER**  
Mass, thou lovedst plums well, that wouldst  
venture so.  

**SIMPCOX**  
Alas, good master, my wife desired some damsons,  
And made me climb, with danger of my life.  

**GLOUCESTER**  
A subtle knave! but yet it shall not serve.  
Let me see thine eyes: wink now: now open them:  
In my opinion yet thou seest not well.  

**SIMPCOX**  
Yes, master, clear as day, I thank God and  
Saint Alban.  

**GLOUCESTER**  
Say'st thou me so? What colour is this cloak of?  

**SIMPCOX**  
Red, master; red as blood.  

**GLOUCESTER**  
Why, that's well said. What colour is my gown of?  

**SIMPCOX**  
Black, forsooth: coal-black as jet.  

**KING HENRY VI**  
Why, then, thou know'st what colour jet is of?  

**SUFFOLK**  
And yet, I think, jet did he never see.  

**GLOUCESTER**  
But cloaks and gowns, before this day, a many.  

**Wife**  
Never, before this day, in all his life.  

**GLOUCESTER**  
Tell me, sirrah, what's my name?  

**SIMPCOX**  
Alas, master, I know not.  

**GLOUCESTER**  
What's his name?  

**SIMPCOX**  
I know not.  

**GLOUCESTER**  
Nor his?  

**SIMPCOX**  
No, indeed, master.  

**GLOUCESTER**  
What's thine own name?  

**SIMPCOX**  
Saunder Simpcox, an if it please you, master.  

**GLOUCESTER**  
Then, Saunder, sit there, the lyingest knave in  
Christendom. If thou hadst been born blind, thou  
mightest as well have known all our names as thus to  
name the several colours we do wear. Sight may  
distinguish of colours, but suddenly to nominate them  
all, it is impossible. My lords, Saint Alban here  
hath done a miracle; and would ye not think his  
cunning to be great, that could restore this cripple  
to his legs again?  

**SIMPCOX**  
O master, that you could!  

**GLOUCESTER**  
My masters of Saint Alban's, have you not beadles in  
your town, and things called whips?  

**Mayor**  
Yes, my lord, if it please your grace.  

**GLOUCESTER**  
Then send for one presently.  

**Mayor**  
Sirrah, go fetch the beadle hither straight.  

_Exit an Attendant_

**GLOUCESTER**  
Now fetch me a stool hither by and by. Now, sirrah,  
if you mean to save yourself from whipping, leap me  
over this stool and run away.  

**SIMPCOX**  
Alas, master, I am not able to stand alone:  
You go about to torture me in vain.  

_Enter a Beadle with whips_

**GLOUCESTER**  
Well, sir, we must have you find your legs. Sirrah  
beadle, whip him till he leap over that same stool.  

**Beadle**  
I will, my lord. Come on, sirrah; off with your  
doublet quickly.  

**SIMPCOX**  
Alas, master, what shall I do? I am not able to stand.  

_After the Beadle hath hit him once, he leaps over the stool and runs away;
and they follow and cry, 'A miracle!'_

**KING HENRY VI**  
O God, seest Thou this, and bearest so long?  

**QUEEN MARGARET**  
It made me laugh to see the villain run.  

**GLOUCESTER**  
Follow the knave; and take this drab away.  

**Wife**  
Alas, sir, we did it for pure need.  

**GLOUCESTER**  
Let them be whipped through every market-town, till  
they come to Berwick, from whence they came.  

_Exeunt Wife, Beadle, Mayor, & c_

**CARDINAL**  
Duke Humphrey has done a miracle to-day.  

**SUFFOLK**  
True; made the lame to leap and fly away.  

**GLOUCESTER**  
But you have done more miracles than I;  
You made in a day, my lord, whole towns to fly.  

_Enter BUCKINGHAM_

**KING HENRY VI**  
What tidings with our cousin Buckingham?  

**BUCKINGHAM**  
Such as my heart doth tremble to unfold.  
A sort of naughty persons, lewdly bent,  
Under the countenance and confederacy  
Of Lady Eleanor, the protector's wife,  
The ringleader and head of all this rout,  
Have practised dangerously against your state,  
Dealing with witches and with conjurers:  
Whom we have apprehended in the fact;  
Raising up wicked spirits from under ground,  
Demanding of King Henry's life and death,  
And other of your highness' privy-council;  
As more at large your grace shall understand.  

**CARDINAL**  
_[Aside to GLOUCESTER]_  
And so, my lord protector,  
by this means  
Your lady is forthcoming yet at London.  
This news, I think, hath turn'd your weapon's edge;  
'Tis like, my lord, you will not keep your hour.  

**GLOUCESTER**  
Ambitious churchman, leave to afflict my heart:  
Sorrow and grief have vanquish'd all my powers;  
And, vanquish'd as I am, I yield to thee,  
Or to the meanest groom.  

**KING HENRY VI**  
O God, what mischiefs work the wicked ones,  
Heaping confusion on their own heads thereby!  

**QUEEN MARGARET**  
Gloucester, see here the tainture of thy nest.  
And look thyself be faultless, thou wert best.  

**GLOUCESTER**  
Madam, for myself, to heaven I do appeal,  
How I have loved my king and commonweal:  
And, for my wife, I know not how it stands;  
Sorry I am to hear what I have heard:  
Noble she is, but if she have forgot  
Honour and virtue and conversed with such  
As, like to pitch, defile nobility,  
I banish her my bed and company  
And give her as a prey to law and shame,  
That hath dishonour'd Gloucester's honest name.  

**KING HENRY VI**  
Well, for this night we will repose us here:  
To-morrow toward London back again,  
To look into this business thoroughly  
And call these foul offenders to their answers  
And poise the cause in justice' equal scales,  
Whose beam stands sure, whose rightful cause prevails.  

_Flourish. Exeunt_

### SCENE II. London. YORK'S garden.

_Enter YORK, SALISBURY, and WARWICK_

**YORK**  
Now, my good Lords of Salisbury and Warwick,  
Our simple supper ended, give me leave  
In this close walk to satisfy myself,  
In craving your opinion of my title,  
Which is infallible, to England's crown.  

**SALISBURY**  
My lord, I long to hear it at full.  

**WARWICK**  
Sweet York, begin: and if thy claim be good,  
The Nevils are thy subjects to command.  

**YORK**  
Then thus:  
Edward the Third, my lords, had seven sons:  
The first, Edward the Black Prince, Prince of Wales;  
The second, William of Hatfield, and the third,  
Lionel Duke of Clarence: next to whom  
Was John of Gaunt, the Duke of Lancaster;  
The fifth was Edmund Langley, Duke of York;  
The sixth was Thomas of Woodstock, Duke of Gloucester;  
William of Windsor was the seventh and last.  
Edward the Black Prince died before his father  
And left behind him Richard, his only son,  
Who after Edward the Third's death reign'd as king;  
Till Henry Bolingbroke, Duke of Lancaster,  
The eldest son and heir of John of Gaunt,  
Crown'd by the name of Henry the Fourth,  
Seized on the realm, deposed the rightful king,  
Sent his poor queen to France, from whence she came,  
And him to Pomfret; where, as all you know,  
Harmless Richard was murder'd traitorously.  

**WARWICK**  
Father, the duke hath told the truth:  
Thus got the house of Lancaster the crown.  

**YORK**  
Which now they hold by force and not by right;  
For Richard, the first son's heir, being dead,  
The issue of the next son should have reign'd.  

**SALISBURY**  
But William of Hatfield died without an heir.  

**YORK**  
The third son, Duke of Clarence, from whose line  
I claimed the crown, had issue, Philippe, a daughter,  
Who married Edmund Mortimer, Earl of March:  
Edmund had issue, Roger Earl of March;  
Roger had issue, Edmund, Anne and Eleanor.  

**SALISBURY**  
This Edmund, in the reign of Bolingbroke,  
As I have read, laid claim unto the crown;  
And, but for Owen Glendower, had been king,  
Who kept him in captivity till he died.  
But to the rest.  

**YORK**  
His eldest sister, Anne,  
My mother, being heir unto the crown  
Married Richard Earl of Cambridge; who was son  
To Edmund Langley, Edward the Third's fifth son.  
By her I claim the kingdom: she was heir  
To Roger Earl of March, who was the son  
Of Edmund Mortimer, who married Philippe,  
Sole daughter unto Lionel Duke of Clarence:  
So, if the issue of the elder son  
Succeed before the younger, I am king.  

**WARWICK**  
What plain proceeding is more plain than this?  
Henry doth claim the crown from John of Gaunt,  
The fourth son; York claims it from the third.  
Till Lionel's issue fails, his should not reign:  
It fails not yet, but flourishes in thee  
And in thy sons, fair slips of such a stock.  
Then, father Salisbury, kneel we together;  
And in this private plot be we the first  
That shall salute our rightful sovereign  
With honour of his birthright to the crown.  

**BOTH**  
Long live our sovereign Richard, England's king!  

**YORK**  
We thank you, lords. But I am not your king  
Till I be crown'd and that my sword be stain'd  
With heart-blood of the house of Lancaster;  
And that's not suddenly to be perform'd,  
But with advice and silent secrecy.  
Do you as I do in these dangerous days:  
Wink at the Duke of Suffolk's insolence,  
At Beaufort's pride, at Somerset's ambition,  
At Buckingham and all the crew of them,  
Till they have snared the shepherd of the flock,  
That virtuous prince, the good Duke Humphrey:  
'Tis that they seek, and they in seeking that  
Shall find their deaths, if York can prophesy.  

**SALISBURY**  
My lord, break we off; we know your mind at full.  

**WARWICK**  
My heart assures me that the Earl of Warwick  
Shall one day make the Duke of York a king.  

**YORK**  
And, Nevil, this I do assure myself:  
Richard shall live to make the Earl of Warwick  
The greatest man in England but the king.  

_Exeunt_

### SCENE III. A hall of justice.

_Sound trumpets. Enter KING HENRY VI, QUEEN MARGARET, GLOUCESTER, YORK,
SUFFOLK, and SALISBURY; the DUCHESS, MARGARET JOURDAIN, SOUTHWELL, HUME, and
BOLINGBROKE, under guard_

**KING HENRY VI**  
Stand forth, Dame Eleanor Cobham, Gloucester's wife:  
In sight of God and us, your guilt is great:  
Receive the sentence of the law for sins  
Such as by God's book are adjudged to death.  
You four, from hence to prison back again;  
From thence unto the place of execution:  
The witch in Smithfield shall be burn'd to ashes,  
And you three shall be strangled on the gallows.  
You, madam, for you are more nobly born,  
Despoiled of your honour in your life,  
Shall, after three days' open penance done,  
Live in your country here in banishment,  
With Sir John Stanley, in the Isle of Man.  

**DUCHESS**  
Welcome is banishment; welcome were my death.  

**GLOUCESTER**  
Eleanor, the law, thou see'st, hath judged thee:  
I cannot justify whom the law condemns.  

_Exeunt DUCHESS and other prisoners, guarded_

Mine eyes are full of tears, my heart of grief.  
Ah, Humphrey, this dishonour in thine age  
Will bring thy head with sorrow to the ground!  
I beseech your majesty, give me leave to go;  
Sorrow would solace and mine age would ease.  

**KING HENRY VI**  
Stay, Humphrey Duke of Gloucester: ere thou go,  
Give up thy staff: Henry will to himself  
Protector be; and God shall be my hope,  
My stay, my guide and lantern to my feet:  
And go in peace, Humphrey, no less beloved  
Than when thou wert protector to thy King.  

**QUEEN MARGARET**  
I see no reason why a king of years  
Should be to be protected like a child.  
God and King Henry govern England's realm.  
Give up your staff, sir, and the king his realm.  

**GLOUCESTER**  
My staff? here, noble Henry, is my staff:  
As willingly do I the same resign  
As e'er thy father Henry made it mine;  
And even as willingly at thy feet I leave it  
As others would ambitiously receive it.  
Farewell, good king: when I am dead and gone,  
May honourable peace attend thy throne!  

_Exit_

**QUEEN MARGARET**  
Why, now is Henry king, and Margaret queen;  
And Humphrey Duke of Gloucester scarce himself,  
That bears so shrewd a maim; two pulls at once;  
His lady banish'd, and a limb lopp'd off.  
This staff of honour raught, there let it stand  
Where it best fits to be, in Henry's hand.  

**SUFFOLK**  
Thus droops this lofty pine and hangs his sprays;  
Thus Eleanor's pride dies in her youngest days.  

**YORK**  
Lords, let him go. Please it your majesty,  
This is the day appointed for the combat;  
And ready are the appellant and defendant,  
The armourer and his man, to enter the lists,  
So please your highness to behold the fight.  

**QUEEN MARGARET**  
Ay, good my lord; for purposely therefore  
Left I the court, to see this quarrel tried.  

**KING HENRY VI**  
O God's name, see the lists and all things fit:  
Here let them end it; and God defend the right!  

**YORK**  
I never saw a fellow worse bested,  
Or more afraid to fight, than is the appellant,  
The servant of this armourer, my lords.  

_Enter at one door, HORNER, the Armourer, and his Neighbours, drinking to
him so much that he is drunk; and he enters with a drum before him and his
staff with a sand-bag fastened to it; and at the other door PETER, his man,
with a drum and sand-bag, and 'Prentices drinking to him_

**First Neighbour**  
Here, neighbour Horner, I drink to you in a cup of  
sack: and fear not, neighbour, you shall do well enough.  

**Second Neighbour**  
And here, neighbour, here's a cup of charneco.  

**Third Neighbour**  
And here's a pot of good double beer, neighbour:  
drink, and fear not your man.  

**HORNER**  
Let it come, i' faith, and I'll pledge you all; and  
a fig for Peter!  
First 'Prentice Here, Peter, I drink to thee: and be not afraid.  
Second 'Prentice Be merry, Peter, and fear not thy master: fight  
for credit of the 'prentices.  

**PETER**  
I thank you all: drink, and pray for me, I pray  
you; for I think I have taken my last draught in  
this world. Here, Robin, an if I die, I give thee  
my apron: and, Will, thou shalt have my hammer:  
and here, Tom, take all the money that I have. O  
Lord bless me! I pray God! for I am never able to  
deal with my master, he hath learnt me so much fence already.  

**SALISBURY**  
Come, leave your drinking, and fall to blows.  
Sirrah, what's thy name?  

**PETER**  
Peter, forsooth.  

**SALISBURY**  
Peter! what more?  

**PETER**  
Thump.  

**SALISBURY**  
Thump! then see thou thump thy master well.  

**HORNER**  
Masters, I am come hither, as it were, upon my man's  
instigation, to prove him a knave and myself an  
honest man: and touching the Duke of York, I will  
take my death, I never meant him any ill, nor the  
king, nor the queen: and therefore, Peter, have at  
thee with a downright blow!  

**YORK**  
Dispatch: this knave's tongue begins to double.  
Sound, trumpets, alarum to the combatants!  

_Alarum. They fight, and PETER strikes him down_

**HORNER**  
Hold, Peter, hold! I confess, I confess treason.  

_Dies_

**YORK**  
Take away his weapon. Fellow, thank God, and the  
good wine in thy master's way.  

**PETER**  
O God, have I overcome mine enemy in this presence?  
O Peter, thou hast prevailed in right!  

**KING HENRY VI**  
Go, take hence that traitor from our sight;  
For his death we do perceive his guilt:  
And God in justice hath revealed to us  
The truth and innocence of this poor fellow,  
Which he had thought to have murder'd wrongfully.  
Come, fellow, follow us for thy reward.  

_Sound a flourish. Exeunt_

### SCENE IV. A street.

_Enter GLOUCESTER and his Servingmen, in mourning cloaks_

**GLOUCESTER**  
Thus sometimes hath the brightest day a cloud;  
And after summer evermore succeeds  
Barren winter, with his wrathful nipping cold:  
So cares and joys abound, as seasons fleet.  
Sirs, what's o'clock?  

**Servants**  
Ten, my lord.  

**GLOUCESTER**  
Ten is the hour that was appointed me  
To watch the coming of my punish'd duchess:  
Uneath may she endure the flinty streets,  
To tread them with her tender-feeling feet.  
Sweet Nell, ill can thy noble mind abrook  
The abject people gazing on thy face,  
With envious looks, laughing at thy shame,  
That erst did follow thy proud chariot-wheels  
When thou didst ride in triumph through the streets.  
But, soft! I think she comes; and I'll prepare  
My tear-stain'd eyes to see her miseries.  

_Enter the DUCHESS in a white sheet, and a taper burning in her hand; with
STANLEY, the Sheriff, and Officers_

**Servant**  
So please your grace, we'll take her from the sheriff.  

**GLOUCESTER**  
No, stir not, for your lives; let her pass by.  

**DUCHESS**  
Come you, my lord, to see my open shame?  
Now thou dost penance too. Look how they gaze!  
See how the giddy multitude do point,  
And nod their heads, and throw their eyes on thee!  
Ah, Gloucester, hide thee from their hateful looks,  
And, in thy closet pent up, rue my shame,  
And ban thine enemies, both mine and thine!  

**GLOUCESTER**  
Be patient, gentle Nell; forget this grief.  

**DUCHESS**  
Ah, Gloucester, teach me to forget myself!  
For whilst I think I am thy married wife  
And thou a prince, protector of this land,  
Methinks I should not thus be led along,  
Mail'd up in shame, with papers on my back,  
And followed with a rabble that rejoice  
To see my tears and hear my deep-fet groans.  
The ruthless flint doth cut my tender feet,  
And when I start, the envious people laugh  
And bid me be advised how I tread.  
Ah, Humphrey, can I bear this shameful yoke?  
Trow'st thou that e'er I'll look upon the world,  
Or count them happy that enjoy the sun?  
No; dark shall be my light and night my day;  
To think upon my pomp shall be my hell.  
Sometime I'll say, I am Duke Humphrey's wife,  
And he a prince and ruler of the land:  
Yet so he ruled and such a prince he was  
As he stood by whilst I, his forlorn duchess,  
Was made a wonder and a pointing-stock  
To every idle rascal follower.  
But be thou mild and blush not at my shame,  
Nor stir at nothing till the axe of death  
Hang over thee, as, sure, it shortly will;  
For Suffolk, he that can do all in all  
With her that hateth thee and hates us all,  
And York and impious Beaufort, that false priest,  
Have all limed bushes to betray thy wings,  
And, fly thou how thou canst, they'll tangle thee:  
But fear not thou, until thy foot be snared,  
Nor never seek prevention of thy foes.  

**GLOUCESTER**  
Ah, Nell, forbear! thou aimest all awry;  
I must offend before I be attainted;  
And had I twenty times so many foes,  
And each of them had twenty times their power,  
All these could not procure me any scathe,  
So long as I am loyal, true and crimeless.  
Wouldst have me rescue thee from this reproach?  
Why, yet thy scandal were not wiped away  
But I in danger for the breach of law.  
Thy greatest help is quiet, gentle Nell:  
I pray thee, sort thy heart to patience;  
These few days' wonder will be quickly worn.  

_Enter a Herald_

**Herald**  
I summon your grace to his majesty's parliament,  
Holden at Bury the first of this next month.  

**GLOUCESTER**  
And my consent ne'er ask'd herein before!  
This is close dealing. Well, I will be there.  

_Exit Herald_

My Nell, I take my leave: and, master sheriff,  
Let not her penance exceed the king's commission.  

**Sheriff**  
An't please your grace, here my commission stays,  
And Sir John Stanley is appointed now  
To take her with him to the Isle of Man.  

**GLOUCESTER**  
Must you, Sir John, protect my lady here?  

**STANLEY**  
So am I given in charge, may't please your grace.  

**GLOUCESTER**  
Entreat her not the worse in that I pray  
You use her well: the world may laugh again;  
And I may live to do you kindness if  
You do it her: and so, Sir John, farewell!  

**DUCHESS**  
What, gone, my lord, and bid me not farewell!  

**GLOUCESTER**  
Witness my tears, I cannot stay to speak.  

_Exeunt GLOUCESTER and Servingmen_

**DUCHESS**  
Art thou gone too? all comfort go with thee!  
For none abides with me: my joy is death;  
Death, at whose name I oft have been afear'd,  
Because I wish'd this world's eternity.  
Stanley, I prithee, go, and take me hence;  
I care not whither, for I beg no favour,  
Only convey me where thou art commanded.  

**STANLEY**  
Why, madam, that is to the Isle of Man;  
There to be used according to your state.  

**DUCHESS**  
That's bad enough, for I am but reproach:  
And shall I then be used reproachfully?  

**STANLEY**  
Like to a duchess, and Duke Humphrey's lady;  
According to that state you shall be used.  

**DUCHESS**  
Sheriff, farewell, and better than I fare,  
Although thou hast been conduct of my shame.  

**Sheriff**  
It is my office; and, madam, pardon me.  

**DUCHESS**  
Ay, ay, farewell; thy office is discharged.  
Come, Stanley, shall we go?  

**STANLEY**  
Madam, your penance done, throw off this sheet,  
And go we to attire you for our journey.  

**DUCHESS**  
My shame will not be shifted with my sheet:  
No, it will hang upon my richest robes  
And show itself, attire me how I can.  
Go, lead the way; I long to see my prison.  

_Exeunt_

# ACT III

### SCENE I. The Abbey at Bury St. Edmund's.

_Sound a sennet. Enter KING HENRY VI, QUEEN MARGARET, CARDINAL, SUFFOLK,
YORK, BUCKINGHAM, SALISBURY and WARWICK to the Parliament_

**KING HENRY VI**  
I muse my Lord of Gloucester is not come:  
'Tis not his wont to be the hindmost man,  
Whate'er occasion keeps him from us now.  

**QUEEN MARGARET**  
Can you not see? or will ye not observe  
The strangeness of his alter'd countenance?  
With what a majesty he bears himself,  
How insolent of late he is become,  
How proud, how peremptory, and unlike himself?  
We know the time since he was mild and affable,  
And if we did but glance a far-off look,  
Immediately he was upon his knee,  
That all the court admired him for submission:  
But meet him now, and, be it in the morn,  
When every one will give the time of day,  
He knits his brow and shows an angry eye,  
And passeth by with stiff unbowed knee,  
Disdaining duty that to us belongs.  
Small curs are not regarded when they grin;  
But great men tremble when the lion roars;  
And Humphrey is no little man in England.  
First note that he is near you in descent,  
And should you fall, he as the next will mount.  
Me seemeth then it is no policy,  
Respecting what a rancorous mind he bears  
And his advantage following your decease,  
That he should come about your royal person  
Or be admitted to your highness' council.  
By flattery hath he won the commons' hearts,  
And when he please to make commotion,  
'Tis to be fear'd they all will follow him.  
Now 'tis the spring, and weeds are shallow-rooted;  
Suffer them now, and they'll o'ergrow the garden  
And choke the herbs for want of husbandry.  
The reverent care I bear unto my lord  
Made me collect these dangers in the duke.  
If it be fond, call it a woman's fear;  
Which fear if better reasons can supplant,  
I will subscribe and say I wrong'd the duke.  
My Lord of Suffolk, Buckingham, and York,  
Reprove my allegation, if you can;  
Or else conclude my words effectual.  

**SUFFOLK**  
Well hath your highness seen into this duke;  
And, had I first been put to speak my mind,  
I think I should have told your grace's tale.  
The duchess, by his subornation,  
Upon my life, began her devilish practises:  
Or, if he were not privy to those faults,  
Yet, by reputing of his high descent,  
As next the king he was successive heir,  
And such high vaunts of his nobility,  
Did instigate the bedlam brain-sick duchess  
By wicked means to frame our sovereign's fall.  
Smooth runs the water where the brook is deep;  
And in his simple show he harbours treason.  
The fox barks not when he would steal the lamb.  
No, no, my sovereign; Gloucester is a man  
Unsounded yet and full of deep deceit.  

**CARDINAL**  
Did he not, contrary to form of law,  
Devise strange deaths for small offences done?  

**YORK**  
And did he not, in his protectorship,  
Levy great sums of money through the realm  
For soldiers' pay in France, and never sent it?  
By means whereof the towns each day revolted.  

**BUCKINGHAM**  
Tut, these are petty faults to faults unknown.  
Which time will bring to light in smooth  
Duke Humphrey.  

**KING HENRY VI**  
My lords, at once: the care you have of us,  
To mow down thorns that would annoy our foot,  
Is worthy praise: but, shall I speak my conscience,  
Our kinsman Gloucester is as innocent  
From meaning treason to our royal person  
As is the sucking lamb or harmless dove:  
The duke is virtuous, mild and too well given  
To dream on evil or to work my downfall.  

**QUEEN MARGARET**  
Ah, what's more dangerous than this fond affiance!  
Seems he a dove? his feathers are but borrowed,  
For he's disposed as the hateful raven:  
Is he a lamb? his skin is surely lent him,  
For he's inclined as is the ravenous wolf.  
Who cannot steal a shape that means deceit?  
Take heed, my lord; the welfare of us all  
Hangs on the cutting short that fraudful man.  

_Enter SOMERSET_

**SOMERSET**  
All health unto my gracious sovereign!  

**KING HENRY VI**  
Welcome, Lord Somerset. What news from France?  

**SOMERSET**  
That all your interest in those territories  
Is utterly bereft you; all is lost.  

**KING HENRY VI**  
Cold news, Lord Somerset: but God's will be done!  

**YORK**  
_[Aside]_  
Cold news for me; for I had hope of France  
As firmly as I hope for fertile England.  
Thus are my blossoms blasted in the bud  
And caterpillars eat my leaves away;  
But I will remedy this gear ere long,  
Or sell my title for a glorious grave.  

_Enter GLOUCESTER_

**GLOUCESTER**  
All happiness unto my lord the king!  
Pardon, my liege, that I have stay'd so long.  

**SUFFOLK**  
Nay, Gloucester, know that thou art come too soon,  
Unless thou wert more loyal than thou art:  
I do arrest thee of high treason here.  

**GLOUCESTER**  
Well, Suffolk, thou shalt not see me blush  
Nor change my countenance for this arrest:  
A heart unspotted is not easily daunted.  
The purest spring is not so free from mud  
As I am clear from treason to my sovereign:  
Who can accuse me? wherein am I guilty?  

**YORK**  
'Tis thought, my lord, that you took bribes of France,  
And, being protector, stayed the soldiers' pay;  
By means whereof his highness hath lost France.  

**GLOUCESTER**  
Is it but thought so? what are they that think it?  
I never robb'd the soldiers of their pay,  
Nor ever had one penny bribe from France.  
So help me God, as I have watch'd the night,  
Ay, night by night, in studying good for England,  
That doit that e'er I wrested from the king,  
Or any groat I hoarded to my use,  
Be brought against me at my trial-day!  
No; many a pound of mine own proper store,  
Because I would not tax the needy commons,  
Have I disbursed to the garrisons,  
And never ask'd for restitution.  

**CARDINAL**  
It serves you well, my lord, to say so much.  

**GLOUCESTER**  
I say no more than truth, so help me God!  

**YORK**  
In your protectorship you did devise  
Strange tortures for offenders never heard of,  
That England was defamed by tyranny.  

**GLOUCESTER**  
Why, 'tis well known that, whiles I was  
protector,  
Pity was all the fault that was in me;  
For I should melt at an offender's tears,  
And lowly words were ransom for their fault.  
Unless it were a bloody murderer,  
Or foul felonious thief that fleeced poor passengers,  
I never gave them condign punishment:  
Murder indeed, that bloody sin, I tortured  
Above the felon or what trespass else.  

**SUFFOLK**  
My lord, these faults are easy, quickly answered:  
But mightier crimes are laid unto your charge,  
Whereof you cannot easily purge yourself.  
I do arrest you in his highness' name;  
And here commit you to my lord cardinal  
To keep, until your further time of trial.  

**KING HENRY VI**  
My lord of Gloucester, 'tis my special hope  
That you will clear yourself from all suspect:  
My conscience tells me you are innocent.  

**GLOUCESTER**  
Ah, gracious lord, these days are dangerous:  
Virtue is choked with foul ambition  
And charity chased hence by rancour's hand;  
Foul subornation is predominant  
And equity exiled your highness' land.  
I know their complot is to have my life,  
And if my death might make this island happy,  
And prove the period of their tyranny,  
I would expend it with all willingness:  
But mine is made the prologue to their play;  
For thousands more, that yet suspect no peril,  
Will not conclude their plotted tragedy.  
Beaufort's red sparkling eyes blab his heart's malice,  
And Suffolk's cloudy brow his stormy hate;  
Sharp Buckingham unburthens with his tongue  
The envious load that lies upon his heart;  
And dogged York, that reaches at the moon,  
Whose overweening arm I have pluck'd back,  
By false accuse doth level at my life:  
And you, my sovereign lady, with the rest,  
Causeless have laid disgraces on my head,  
And with your best endeavour have stirr'd up  
My liefest liege to be mine enemy:  
Ay, all you have laid your heads together--  
Myself had notice of your conventicles--  
And all to make away my guiltless life.  
I shall not want false witness to condemn me,  
Nor store of treasons to augment my guilt;  
The ancient proverb will be well effected:  
'A staff is quickly found to beat a dog.'  

**CARDINAL**  
My liege, his railing is intolerable:  
If those that care to keep your royal person  
From treason's secret knife and traitors' rage  
Be thus upbraided, chid and rated at,  
And the offender granted scope of speech,  
'Twill make them cool in zeal unto your grace.  

**SUFFOLK**  
Hath he not twit our sovereign lady here  
With ignominious words, though clerkly couch'd,  
As if she had suborned some to swear  
False allegations to o'erthrow his state?  

**QUEEN MARGARET**  
But I can give the loser leave to chide.  

**GLOUCESTER**  
Far truer spoke than meant: I lose, indeed;  
Beshrew the winners, for they play'd me false!  
And well such losers may have leave to speak.  

**BUCKINGHAM**  
He'll wrest the sense and hold us here all day:  
Lord cardinal, he is your prisoner.  

**CARDINAL**  
Sirs, take away the duke, and guard him sure.  

**GLOUCESTER**  
Ah! thus King Henry throws away his crutch  
Before his legs be firm to bear his body.  
Thus is the shepherd beaten from thy side,  
And wolves are gnarling who shall gnaw thee first.  
Ah, that my fear were false! ah, that it were!  
For, good King Henry, thy decay I fear.  

_Exit, guarded_

**KING HENRY VI**  
My lords, what to your wisdoms seemeth best,  
Do or undo, as if ourself were here.  

**QUEEN MARGARET**  
What, will your highness leave the parliament?  

**KING HENRY VI**  
Ay, Margaret; my heart is drown'd with grief,  
Whose flood begins to flow within mine eyes,  
My body round engirt with misery,  
For what's more miserable than discontent?  
Ah, uncle Humphrey! in thy face I see  
The map of honour, truth and loyalty:  
And yet, good Humphrey, is the hour to come  
That e'er I proved thee false or fear'd thy faith.  
What louring star now envies thy estate,  
That these great lords and Margaret our queen  
Do seek subversion of thy harmless life?  
Thou never didst them wrong, nor no man wrong;  
And as the butcher takes away the calf  
And binds the wretch, and beats it when it strays,  
Bearing it to the bloody slaughter-house,  
Even so remorseless have they borne him hence;  
And as the dam runs lowing up and down,  
Looking the way her harmless young one went,  
And can do nought but wail her darling's loss,  
Even so myself bewails good Gloucester's case  
With sad unhelpful tears, and with dimm'd eyes  
Look after him and cannot do him good,  
So mighty are his vowed enemies.  
His fortunes I will weep; and, 'twixt each groan  
Say 'Who's a traitor? Gloucester he is none.'  

_Exeunt all but QUEEN MARGARET, CARDINAL, SUFFOLK, and YORK; SOMERSET
remains apart_

**QUEEN MARGARET**  
Free lords, cold snow melts with the sun's hot beams.  
Henry my lord is cold in great affairs,  
Too full of foolish pity, and Gloucester's show  
Beguiles him as the mournful crocodile  
With sorrow snares relenting passengers,  
Or as the snake roll'd in a flowering bank,  
With shining chequer'd slough, doth sting a child  
That for the beauty thinks it excellent.  
Believe me, lords, were none more wise than I--  
And yet herein I judge mine own wit good--  
This Gloucester should be quickly rid the world,  
To rid us of the fear we have of him.  

**CARDINAL**  
That he should die is worthy policy;  
But yet we want a colour for his death:  
'Tis meet he be condemn'd by course of law.  

**SUFFOLK**  
But, in my mind, that were no policy:  
The king will labour still to save his life,  
The commons haply rise, to save his life;  
And yet we have but trivial argument,  
More than mistrust, that shows him worthy death.  

**YORK**  
So that, by this, you would not have him die.  

**SUFFOLK**  
Ah, York, no man alive so fain as I!  

**YORK**  
'Tis York that hath more reason for his death.  
But, my lord cardinal, and you, my Lord of Suffolk,  
Say as you think, and speak it from your souls,  
Were't not all one, an empty eagle were set  
To guard the chicken from a hungry kite,  
As place Duke Humphrey for the king's protector?  

**QUEEN MARGARET**  
So the poor chicken should be sure of death.  

**SUFFOLK**  
Madam, 'tis true; and were't not madness, then,  
To make the fox surveyor of the fold?  
Who being accused a crafty murderer,  
His guilt should be but idly posted over,  
Because his purpose is not executed.  
No; let him die, in that he is a fox,  
By nature proved an enemy to the flock,  
Before his chaps be stain'd with crimson blood,  
As Humphrey, proved by reasons, to my liege.  
And do not stand on quillets how to slay him:  
Be it by gins, by snares, by subtlety,  
Sleeping or waking, 'tis no matter how,  
So he be dead; for that is good deceit  
Which mates him first that first intends deceit.  

**QUEEN MARGARET**  
Thrice-noble Suffolk, 'tis resolutely spoke.  

**SUFFOLK**  
Not resolute, except so much were done;  
For things are often spoke and seldom meant:  
But that my heart accordeth with my tongue,  
Seeing the deed is meritorious,  
And to preserve my sovereign from his foe,  
Say but the word, and I will be his priest.  

**CARDINAL**  
But I would have him dead, my Lord of Suffolk,  
Ere you can take due orders for a priest:  
Say you consent and censure well the deed,  
And I'll provide his executioner,  
I tender so the safety of my liege.  

**SUFFOLK**  
Here is my hand, the deed is worthy doing.  

**QUEEN MARGARET**  
And so say I.  

**YORK**  
And I and now we three have spoke it,  
It skills not greatly who impugns our doom.  

_Enter a Post_

**Post**  
Great lords, from Ireland am I come amain,  
To signify that rebels there are up  
And put the Englishmen unto the sword:  
Send succors, lords, and stop the rage betime,  
Before the wound do grow uncurable;  
For, being green, there is great hope of help.  

**CARDINAL**  
A breach that craves a quick expedient stop!  
What counsel give you in this weighty cause?  

**YORK**  
That Somerset be sent as regent thither:  
'Tis meet that lucky ruler be employ'd;  
Witness the fortune he hath had in France.  

**SOMERSET**  
If York, with all his far-fet policy,  
Had been the regent there instead of me,  
He never would have stay'd in France so long.  

**YORK**  
No, not to lose it all, as thou hast done:  
I rather would have lost my life betimes  
Than bring a burthen of dishonour home  
By staying there so long till all were lost.  
Show me one scar character'd on thy skin:  
Men's flesh preserved so whole do seldom win.  

**QUEEN MARGARET**  
Nay, then, this spark will prove a raging fire,  
If wind and fuel be brought to feed it with:  
No more, good York; sweet Somerset, be still:  
Thy fortune, York, hadst thou been regent there,  
Might happily have proved far worse than his.  

**YORK**  
What, worse than nought? nay, then, a shame take all!  

**SOMERSET**  
And, in the number, thee that wishest shame!  

**CARDINAL**  
My Lord of York, try what your fortune is.  
The uncivil kerns of Ireland are in arms  
And temper clay with blood of Englishmen:  
To Ireland will you lead a band of men,  
Collected choicely, from each county some,  
And try your hap against the Irishmen?  

**YORK**  
I will, my lord, so please his majesty.  

**SUFFOLK**  
Why, our authority is his consent,  
And what we do establish he confirms:  
Then, noble York, take thou this task in hand.  

**YORK**  
I am content: provide me soldiers, lords,  
Whiles I take order for mine own affairs.  

**SUFFOLK**  
A charge, Lord York, that I will see perform'd.  
But now return we to the false Duke Humphrey.  

**CARDINAL**  
No more of him; for I will deal with him  
That henceforth he shall trouble us no more.  
And so break off; the day is almost spent:  
Lord Suffolk, you and I must talk of that event.  

**YORK**  
My Lord of Suffolk, within fourteen days  
At Bristol I expect my soldiers;  
For there I'll ship them all for Ireland.  

**SUFFOLK**  
I'll see it truly done, my Lord of York.  

_Exeunt all but YORK_

**YORK**  
Now, York, or never, steel thy fearful thoughts,  
And change misdoubt to resolution:  
Be that thou hopest to be, or what thou art  
Resign to death; it is not worth the enjoying:  
Let pale-faced fear keep with the mean-born man,  
And find no harbour in a royal heart.  
Faster than spring-time showers comes thought  
on thought,  
And not a thought but thinks on dignity.  
My brain more busy than the labouring spider  
Weaves tedious snares to trap mine enemies.  
Well, nobles, well, 'tis politicly done,  
To send me packing with an host of men:  
I fear me you but warm the starved snake,  
Who, cherish'd in your breasts, will sting  
your hearts.  
'Twas men I lack'd and you will give them me:  
I take it kindly; and yet be well assured  
You put sharp weapons in a madman's hands.  
Whiles I in Ireland nourish a mighty band,  
I will stir up in England some black storm  
Shall blow ten thousand souls to heaven or hell;  
And this fell tempest shall not cease to rage  
Until the golden circuit on my head,  
Like to the glorious sun's transparent beams,  
Do calm the fury of this mad-bred flaw.  
And, for a minister of my intent,  
I have seduced a headstrong Kentishman,  
John Cade of Ashford,  
To make commotion, as full well he can,  
Under the title of John Mortimer.  
In Ireland have I seen this stubborn Cade  
Oppose himself against a troop of kerns,  
And fought so long, till that his thighs with darts  
Were almost like a sharp-quill'd porpentine;  
And, in the end being rescued, I have seen  
Him caper upright like a wild Morisco,  
Shaking the bloody darts as he his bells.  
Full often, like a shag-hair'd crafty kern,  
Hath he conversed with the enemy,  
And undiscover'd come to me again  
And given me notice of their villanies.  
This devil here shall be my substitute;  
For that John Mortimer, which now is dead,  
In face, in gait, in speech, he doth resemble:  
By this I shall perceive the commons' mind,  
How they affect the house and claim of York.  
Say he be taken, rack'd and tortured,  
I know no pain they can inflict upon him  
Will make him say I moved him to those arms.  
Say that he thrive, as 'tis great like he will,  
Why, then from Ireland come I with my strength  
And reap the harvest which that rascal sow'd;  
For Humphrey being dead, as he shall be,  
And Henry put apart, the next for me.  

_Exit_

### SCENE II. Bury St. Edmund's. A room of state.

_Enter certain Murderers, hastily_

**First Murderer**  
Run to my Lord of Suffolk; let him know  
We have dispatch'd the duke, as he commanded.  

**Second Murderer**  
O that it were to do! What have we done?  
Didst ever hear a man so penitent?  

_Enter SUFFOLK_

**First Murder**  
Here comes my lord.  

**SUFFOLK**  
Now, sirs, have you dispatch'd this thing?  

**First Murderer**  
Ay, my good lord, he's dead.  

**SUFFOLK**  
Why, that's well said. Go, get you to my house;  
I will reward you for this venturous deed.  
The king and all the peers are here at hand.  
Have you laid fair the bed? Is all things well,  
According as I gave directions?  

**First Murderer**  
'Tis, my good lord.  

**SUFFOLK**  
Away! be gone.  

_Exeunt Murderers_

_Sound trumpets. Enter KING HENRY VI, QUEEN MARGARET, CARDINAL, SOMERSET,
with Attendants_

**KING HENRY VI**  
Go, call our uncle to our presence straight;  
Say we intend to try his grace to-day.  
If he be guilty, as 'tis published.  

**SUFFOLK**  
I'll call him presently, my noble lord.  

_Exit_

**KING HENRY VI**  
Lords, take your places; and, I pray you all,  
Proceed no straiter 'gainst our uncle Gloucester  
Than from true evidence of good esteem  
He be approved in practise culpable.  

**QUEEN MARGARET**  
God forbid any malice should prevail,  
That faultless may condemn a nobleman!  
Pray God he may acquit him of suspicion!  

**KING HENRY VI**  
I thank thee, Meg; these words content me much.  

_Re-enter SUFFOLK_

How now! why look'st thou pale? why tremblest thou?  
Where is our uncle? what's the matter, Suffolk?  

**SUFFOLK**  
Dead in his bed, my lord; Gloucester is dead.  

**QUEEN MARGARET**  
Marry, God forfend!  

**CARDINAL**  
God's secret judgment: I did dream to-night  
The duke was dumb and could not speak a word.  

_KING HENRY VI swoons_

**QUEEN MARGARET**  
How fares my lord? Help, lords! the king is dead.  

**SOMERSET**  
Rear up his body; wring him by the nose.  

**QUEEN MARGARET**  
Run, go, help, help! O Henry, ope thine eyes!  

**SUFFOLK**  
He doth revive again: madam, be patient.  

**KING HENRY VI**  
O heavenly God!  

**QUEEN MARGARET**  
How fares my gracious lord?  

**SUFFOLK**  
Comfort, my sovereign! gracious Henry, comfort!  

**KING HENRY VI**  
What, doth my Lord of Suffolk comfort me?  
Came he right now to sing a raven's note,  
Whose dismal tune bereft my vital powers;  
And thinks he that the chirping of a wren,  
By crying comfort from a hollow breast,  
Can chase away the first-conceived sound?  
Hide not thy poison with such sugar'd words;  
Lay not thy hands on me; forbear, I say;  
Their touch affrights me as a serpent's sting.  
Thou baleful messenger, out of my sight!  
Upon thy eye-balls murderous tyranny  
Sits in grim majesty, to fright the world.  
Look not upon me, for thine eyes are wounding:  
Yet do not go away: come, basilisk,  
And kill the innocent gazer with thy sight;  
For in the shade of death I shall find joy;  
In life but double death, now Gloucester's dead.  

**QUEEN MARGARET**  
Why do you rate my Lord of Suffolk thus?  
Although the duke was enemy to him,  
Yet he most Christian-like laments his death:  
And for myself, foe as he was to me,  
Might liquid tears or heart-offending groans  
Or blood-consuming sighs recall his life,  
I would be blind with weeping, sick with groans,  
Look pale as primrose with blood-drinking sighs,  
And all to have the noble duke alive.  
What know I how the world may deem of me?  
For it is known we were but hollow friends:  
It may be judged I made the duke away;  
So shall my name with slander's tongue be wounded,  
And princes' courts be fill'd with my reproach.  
This get I by his death: ay me, unhappy!  
To be a queen, and crown'd with infamy!  

**KING HENRY VI**  
Ah, woe is me for Gloucester, wretched man!  

**QUEEN MARGARET**  
Be woe for me, more wretched than he is.  
What, dost thou turn away and hide thy face?  
I am no loathsome leper; look on me.  
What! art thou, like the adder, waxen deaf?  
Be poisonous too and kill thy forlorn queen.  
Is all thy comfort shut in Gloucester's tomb?  
Why, then, dame Margaret was ne'er thy joy.  
Erect his statue and worship it,  
And make my image but an alehouse sign.  
Was I for this nigh wreck'd upon the sea  
And twice by awkward wind from England's bank  
Drove back again unto my native clime?  
What boded this, but well forewarning wind  
Did seem to say 'Seek not a scorpion's nest,  
Nor set no footing on this unkind shore'?  
What did I then, but cursed the gentle gusts  
And he that loosed them forth their brazen caves:  
And bid them blow towards England's blessed shore,  
Or turn our stern upon a dreadful rock  
Yet AEolus would not be a murderer,  
But left that hateful office unto thee:  
The pretty-vaulting sea refused to drown me,  
Knowing that thou wouldst have me drown'd on shore,  
With tears as salt as sea, through thy unkindness:  
The splitting rocks cower'd in the sinking sands  
And would not dash me with their ragged sides,  
Because thy flinty heart, more hard than they,  
Might in thy palace perish Margaret.  
As far as I could ken thy chalky cliffs,  
When from thy shore the tempest beat us back,  
I stood upon the hatches in the storm,  
And when the dusky sky began to rob  
My earnest-gaping sight of thy land's view,  
I took a costly jewel from my neck,  
A heart it was, bound in with diamonds,  
And threw it towards thy land: the sea received it,  
And so I wish'd thy body might my heart:  
And even with this I lost fair England's view  
And bid mine eyes be packing with my heart  
And call'd them blind and dusky spectacles,  
For losing ken of Albion's wished coast.  
How often have I tempted Suffolk's tongue,  
The agent of thy foul inconstancy,  
To sit and witch me, as Ascanius did  
When he to madding Dido would unfold  
His father's acts commenced in burning Troy!  
Am I not witch'd like her? or thou not false like him?  
Ay me, I can no more! die, Margaret!  
For Henry weeps that thou dost live so long.  

_Noise within. Enter WARWICK, SALISBURY, and many Commons_

**WARWICK**  
It is reported, mighty sovereign,  
That good Duke Humphrey traitorously is murder'd  
By Suffolk and the Cardinal Beaufort's means.  
The commons, like an angry hive of bees  
That want their leader, scatter up and down  
And care not who they sting in his revenge.  
Myself have calm'd their spleenful mutiny,  
Until they hear the order of his death.  

**KING HENRY VI**  
That he is dead, good Warwick, 'tis too true;  
But how he died God knows, not Henry:  
Enter his chamber, view his breathless corpse,  
And comment then upon his sudden death.  

**WARWICK**  
That shall I do, my liege. Stay, Salisbury,  
With the rude multitude till I return.  

_Exit_

**KING HENRY VI**  
O Thou that judgest all things, stay my thoughts,  
My thoughts, that labour to persuade my soul  
Some violent hands were laid on Humphrey's life!  
If my suspect be false, forgive me, God,  
For judgment only doth belong to thee.  
Fain would I go to chafe his paly lips  
With twenty thousand kisses, and to drain  
Upon his face an ocean of salt tears,  
To tell my love unto his dumb deaf trunk,  
And with my fingers feel his hand unfeeling:  
But all in vain are these mean obsequies;  
And to survey his dead and earthly image,  
What were it but to make my sorrow greater?  

_Re-enter WARWICK and others, bearing GLOUCESTER 'S body on a bed_

**WARWICK**  
Come hither, gracious sovereign, view this body.  

**KING HENRY VI**  
That is to see how deep my grave is made;  
For with his soul fled all my worldly solace,  
For seeing him I see my life in death.  

**WARWICK**  
As surely as my soul intends to live  
With that dread King that took our state upon him  
To free us from his father's wrathful curse,  
I do believe that violent hands were laid  
Upon the life of this thrice-famed duke.  

**SUFFOLK**  
A dreadful oath, sworn with a solemn tongue!  
What instance gives Lord Warwick for his vow?  

**WARWICK**  
See how the blood is settled in his face.  
Oft have I seen a timely-parted ghost,  
Of ashy semblance, meagre, pale and bloodless,  
Being all descended to the labouring heart;  
Who, in the conflict that it holds with death,  
Attracts the same for aidance 'gainst the enemy;  
Which with the heart there cools and ne'er returneth  
To blush and beautify the cheek again.  
But see, his face is black and full of blood,  
His eye-balls further out than when he lived,  
Staring full ghastly like a strangled man;  
His hair uprear'd, his nostrils stretched with struggling;  
His hands abroad display'd, as one that grasp'd  
And tugg'd for life and was by strength subdued:  
Look, on the sheets his hair you see, is sticking;  
His well-proportion'd beard made rough and rugged,  
Like to the summer's corn by tempest lodged.  
It cannot be but he was murder'd here;  
The least of all these signs were probable.  

**SUFFOLK**  
Why, Warwick, who should do the duke to death?  
Myself and Beaufort had him in protection;  
And we, I hope, sir, are no murderers.  

**WARWICK**  
But both of you were vow'd Duke Humphrey's foes,  
And you, forsooth, had the good duke to keep:  
'Tis like you would not feast him like a friend;  
And 'tis well seen he found an enemy.  

**QUEEN MARGARET**  
Then you, belike, suspect these noblemen  
As guilty of Duke Humphrey's timeless death.  

**WARWICK**  
Who finds the heifer dead and bleeding fresh  
And sees fast by a butcher with an axe,  
But will suspect 'twas he that made the slaughter?  
Who finds the partridge in the puttock's nest,  
But may imagine how the bird was dead,  
Although the kite soar with unbloodied beak?  
Even so suspicious is this tragedy.  

**QUEEN MARGARET**  
Are you the butcher, Suffolk? Where's your knife?  
Is Beaufort term'd a kite? Where are his talons?  

**SUFFOLK**  
I wear no knife to slaughter sleeping men;  
But here's a vengeful sword, rusted with ease,  
That shall be scoured in his rancorous heart  
That slanders me with murder's crimson badge.  
Say, if thou darest, proud Lord of Warwick-shire,  
That I am faulty in Duke Humphrey's death.  

_Exeunt CARDINAL, SOMERSET, and others_

**WARWICK**  
What dares not Warwick, if false Suffolk dare him?  

**QUEEN MARGARET**  
He dares not calm his contumelious spirit  
Nor cease to be an arrogant controller,  
Though Suffolk dare him twenty thousand times.  

**WARWICK**  
Madam, be still; with reverence may I say;  
For every word you speak in his behalf  
Is slander to your royal dignity.  

**SUFFOLK**  
Blunt-witted lord, ignoble in demeanor!  
If ever lady wrong'd her lord so much,  
Thy mother took into her blameful bed  
Some stern untutor'd churl, and noble stock  
Was graft with crab-tree slip; whose fruit thou art,  
And never of the Nevils' noble race.  

**WARWICK**  
But that the guilt of murder bucklers thee  
And I should rob the deathsman of his fee,  
Quitting thee thereby of ten thousand shames,  
And that my sovereign's presence makes me mild,  
I would, false murderous coward, on thy knee  
Make thee beg pardon for thy passed speech,  
And say it was thy mother that thou meant'st  
That thou thyself was born in bastardy;  
And after all this fearful homage done,  
Give thee thy hire and send thy soul to hell,  
Pernicious blood-sucker of sleeping men!  

**SUFFOLK**  
Thou shall be waking well I shed thy blood,  
If from this presence thou darest go with me.  

**WARWICK**  
Away even now, or I will drag thee hence:  
Unworthy though thou art, I'll cope with thee  
And do some service to Duke Humphrey's ghost.  

_Exeunt SUFFOLK and WARWICK_

**KING HENRY VI**  
What stronger breastplate than a heart untainted!  
Thrice is he armed that hath his quarrel just,  
And he but naked, though lock'd up in steel  
Whose conscience with injustice is corrupted.  

_A noise within_

**QUEEN MARGARET**  
What noise is this?  

_Re-enter SUFFOLK and WARWICK, with their weapons drawn_

**KING HENRY VI**  
Why, how now, lords! your wrathful weapons drawn  
Here in our presence! dare you be so bold?  
Why, what tumultuous clamour have we here?  

**SUFFOLK**  
The traitorous Warwick with the men of Bury  
Set all upon me, mighty sovereign.  

**SALISBURY**  
_[To the Commons, entering]_  
Sirs, stand apart;  
the king shall know your mind.  
Dread lord, the commons send you word by me,  
Unless Lord Suffolk straight be done to death,  
Or banished fair England's territories,  
They will by violence tear him from your palace  
And torture him with grievous lingering death.  
They say, by him the good Duke Humphrey died;  
They say, in him they fear your highness' death;  
And mere instinct of love and loyalty,  
Free from a stubborn opposite intent,  
As being thought to contradict your liking,  
Makes them thus forward in his banishment.  
They say, in care of your most royal person,  
That if your highness should intend to sleep  
And charge that no man should disturb your rest  
In pain of your dislike or pain of death,  
Yet, notwithstanding such a strait edict,  
Were there a serpent seen, with forked tongue,  
That slily glided towards your majesty,  
It were but necessary you were waked,  
Lest, being suffer'd in that harmful slumber,  
The mortal worm might make the sleep eternal;  
And therefore do they cry, though you forbid,  
That they will guard you, whether you will or no,  
From such fell serpents as false Suffolk is,  
With whose envenomed and fatal sting,  
Your loving uncle, twenty times his worth,  
They say, is shamefully bereft of life.  

**Commons**  
_[Within]_  
An answer from the king, my  
Lord of Salisbury!  

**SUFFOLK**  
'Tis like the commons, rude unpolish'd hinds,  
Could send such message to their sovereign:  
But you, my lord, were glad to be employ'd,  
To show how quaint an orator you are:  
But all the honour Salisbury hath won  
Is, that he was the lord ambassador  
Sent from a sort of tinkers to the king.  

**Commons**  
_[Within]_  
An answer from the king, or we will all break in!  

**KING HENRY VI**  
Go, Salisbury, and tell them all from me.  
I thank them for their tender loving care;  
And had I not been cited so by them,  
Yet did I purpose as they do entreat;  
For, sure, my thoughts do hourly prophesy  
Mischance unto my state by Suffolk's means:  
And therefore, by His majesty I swear,  
Whose far unworthy deputy I am,  
He shall not breathe infection in this air  
But three days longer, on the pain of death.  

_Exit SALISBURY_

**QUEEN MARGARET**  
O Henry, let me plead for gentle Suffolk!  

**KING HENRY VI**  
Ungentle queen, to call him gentle Suffolk!  
No more, I say: if thou dost plead for him,  
Thou wilt but add increase unto my wrath.  
Had I but said, I would have kept my word,  
But when I swear, it is irrevocable.  
If, after three days' space, thou here be'st found  
On any ground that I am ruler of,  
The world shall not be ransom for thy life.  
Come, Warwick, come, good Warwick, go with me;  
I have great matters to impart to thee.  

_Exeunt all but QUEEN MARGARET and SUFFOLK_

**QUEEN MARGARET**  
Mischance and sorrow go along with you!  
Heart's discontent and sour affliction  
Be playfellows to keep you company!  
There's two of you; the devil make a third!  
And threefold vengeance tend upon your steps!  

**SUFFOLK**  
Cease, gentle queen, these execrations,  
And let thy Suffolk take his heavy leave.  

**QUEEN MARGARET**  
Fie, coward woman and soft-hearted wretch!  
Hast thou not spirit to curse thine enemy?  

**SUFFOLK**  
A plague upon them! wherefore should I curse them?  
Would curses kill, as doth the mandrake's groan,  
I would invent as bitter-searching terms,  
As curst, as harsh and horrible to hear,  
Deliver'd strongly through my fixed teeth,  
With full as many signs of deadly hate,  
As lean-faced Envy in her loathsome cave:  
My tongue should stumble in mine earnest words;  
Mine eyes should sparkle like the beaten flint;  
Mine hair be fixed on end, as one distract;  
Ay, every joint should seem to curse and ban:  
And even now my burthen'd heart would break,  
Should I not curse them. Poison be their drink!  
Gall, worse than gall, the daintiest that they taste!  
Their sweetest shade a grove of cypress trees!  
Their chiefest prospect murdering basilisks!  
Their softest touch as smart as lizards' sting!  
Their music frightful as the serpent's hiss,  
And boding screech-owls make the concert full!  
All the foul terrors in dark-seated hell--  

**QUEEN MARGARET**  
Enough, sweet Suffolk; thou torment'st thyself;  
And these dread curses, like the sun 'gainst glass,  
Or like an overcharged gun, recoil,  
And turn the force of them upon thyself.  

**SUFFOLK**  
You bade me ban, and will you bid me leave?  
Now, by the ground that I am banish'd from,  
Well could I curse away a winter's night,  
Though standing naked on a mountain top,  
Where biting cold would never let grass grow,  
And think it but a minute spent in sport.  

**QUEEN MARGARET**  
O, let me entreat thee cease. Give me thy hand,  
That I may dew it with my mournful tears;  
Nor let the rain of heaven wet this place,  
To wash away my woful monuments.  
O, could this kiss be printed in thy hand,  
That thou mightst think upon these by the seal,  
Through whom a thousand sighs are breathed for thee!  
So, get thee gone, that I may know my grief;  
'Tis but surmised whiles thou art standing by,  
As one that surfeits thinking on a want.  
I will repeal thee, or, be well assured,  
Adventure to be banished myself:  
And banished I am, if but from thee.  
Go; speak not to me; even now be gone.  
O, go not yet! Even thus two friends condemn'd  
Embrace and kiss and take ten thousand leaves,  
Loather a hundred times to part than die.  
Yet now farewell; and farewell life with thee!  

**SUFFOLK**  
Thus is poor Suffolk ten times banished;  
Once by the king, and three times thrice by thee.  
'Tis not the land I care for, wert thou thence;  
A wilderness is populous enough,  
So Suffolk had thy heavenly company:  
For where thou art, there is the world itself,  
With every several pleasure in the world,  
And where thou art not, desolation.  
I can no more: live thou to joy thy life;  
Myself no joy in nought but that thou livest.  

_Enter VAUX_

**QUEEN MARGARET**  
Wither goes Vaux so fast? what news, I prithee?  

**VAUX**  
To signify unto his majesty  
That Cardinal Beaufort is at point of death;  
For suddenly a grievous sickness took him,  
That makes him gasp and stare and catch the air,  
Blaspheming God and cursing men on earth.  
Sometimes he talks as if Duke Humphrey's ghost  
Were by his side; sometime he calls the king,  
And whispers to his pillow, as to him,  
The secrets of his overcharged soul;  
And I am sent to tell his majesty  
That even now he cries aloud for him.  

**QUEEN MARGARET**  
Go tell this heavy message to the king.  

_Exit VAUX_

Ay me! what is this world! what news are these!  
But wherefore grieve I at an hour's poor loss,  
Omitting Suffolk's exile, my soul's treasure?  
Why only, Suffolk, mourn I not for thee,  
And with the southern clouds contend in tears,  
Theirs for the earth's increase, mine for my sorrows?  
Now get thee hence: the king, thou know'st, is coming;  
If thou be found by me, thou art but dead.  

**SUFFOLK**  
If I depart from thee, I cannot live;  
And in thy sight to die, what were it else  
But like a pleasant slumber in thy lap?  
Here could I breathe my soul into the air,  
As mild and gentle as the cradle-babe  
Dying with mother's dug between its lips:  
Where, from thy sight, I should be raging mad,  
And cry out for thee to close up mine eyes,  
To have thee with thy lips to stop my mouth;  
So shouldst thou either turn my flying soul,  
Or I should breathe it so into thy body,  
And then it lived in sweet Elysium.  
To die by thee were but to die in jest;  
From thee to die were torture more than death:  
O, let me stay, befall what may befall!  

**QUEEN MARGARET**  
Away! though parting be a fretful corrosive,  
It is applied to a deathful wound.  
To France, sweet Suffolk: let me hear from thee;  
For wheresoe'er thou art in this world's globe,  
I'll have an Iris that shall find thee out.  

**SUFFOLK**  
I go.  

**QUEEN MARGARET**  
And take my heart with thee.  

**SUFFOLK**  
A jewel, lock'd into the wofull'st cask  
That ever did contain a thing of worth.  
Even as a splitted bark, so sunder we  
This way fall I to death.  

**QUEEN MARGARET**  
This way for me.  

_Exeunt severally_

### SCENE III. A bedchamber.

_Enter the KING, SALISBURY, WARWICK, to the CARDINAL in bed_

**KING HENRY VI**  
How fares my lord? speak, Beaufort, to  
thy sovereign.  

**CARDINAL**  
If thou be'st death, I'll give thee England's treasure,  
Enough to purchase such another island,  
So thou wilt let me live, and feel no pain.  

**KING HENRY VI**  
Ah, what a sign it is of evil life,  
Where death's approach is seen so terrible!  

**WARWICK**  
Beaufort, it is thy sovereign speaks to thee.  

**CARDINAL**  
Bring me unto my trial when you will.  
Died he not in his bed? where should he die?  
Can I make men live, whether they will or no?  
O, torture me no more! I will confess.  
Alive again? then show me where he is:  
I'll give a thousand pound to look upon him.  
He hath no eyes, the dust hath blinded them.  
Comb down his hair; look, look! it stands upright,  
Like lime-twigs set to catch my winged soul.  
Give me some drink; and bid the apothecary  
Bring the strong poison that I bought of him.  

**KING HENRY VI**  
O thou eternal Mover of the heavens.  
Look with a gentle eye upon this wretch!  
O, beat away the busy meddling fiend  
That lays strong siege unto this wretch's soul.  
And from his bosom purge this black despair!  

**WARWICK**  
See, how the pangs of death do make him grin!  

**SALISBURY**  
Disturb him not; let him pass peaceably.  

**KING HENRY VI**  
Peace to his soul, if God's good pleasure be!  
Lord cardinal, if thou think'st on heaven's bliss,  
Hold up thy hand, make signal of thy hope.  
He dies, and makes no sign. O God, forgive him!  

**WARWICK**  
So bad a death argues a monstrous life.  

**KING HENRY VI**  
Forbear to judge, for we are sinners all.  
Close up his eyes and draw the curtain close;  
And let us all to meditation.  

_Exeunt_

# ACT IV

### SCENE I. The coast of Kent.

_Alarum. Fight at sea. Ordnance goes off. Enter a Captain, a Master, a
Master 's-mate, WALTER WHITMORE, and others; with them SUFFOLK, and others,
prisoners_

**Captain**  
The gaudy, blabbing and remorseful day  
Is crept into the bosom of the sea;  
And now loud-howling wolves arouse the jades  
That drag the tragic melancholy night;  
Who, with their drowsy, slow and flagging wings,  
Clip dead men's graves and from their misty jaws  
Breathe foul contagious darkness in the air.  
Therefore bring forth the soldiers of our prize;  
For, whilst our pinnace anchors in the Downs,  
Here shall they make their ransom on the sand,  
Or with their blood stain this discolour'd shore.  
Master, this prisoner freely give I thee;  
And thou that art his mate, make boot of this;  
The other, Walter Whitmore, is thy share.  

**First Gentleman**  
What is my ransom, master? let me know.  

**Master**  
A thousand crowns, or else lay down your head.  
Master's-Mate And so much shall you give, or off goes yours.  

**Captain**  
What, think you much to pay two thousand crowns,  
And bear the name and port of gentlemen?  
Cut both the villains' throats; for die you shall:  
The lives of those which we have lost in fight  
Be counterpoised with such a petty sum!  

**First Gentleman**  
I'll give it, sir; and therefore spare my life.  

**Second Gentleman**  
And so will I and write home for it straight.  

**WHITMORE**  
I lost mine eye in laying the prize aboard,  
And therefore to revenge it, shalt thou die;  

_To SUFFOLK_

And so should these, if I might have my will.  

**Captain**  
Be not so rash; take ransom, let him live.  

**SUFFOLK**  
Look on my George; I am a gentleman:  
Rate me at what thou wilt, thou shalt be paid.  

**WHITMORE**  
And so am I; my name is Walter Whitmore.  
How now! why start'st thou? what, doth  
death affright?  

**SUFFOLK**  
Thy name affrights me, in whose sound is death.  
A cunning man did calculate my birth  
And told me that by water I should die:  
Yet let not this make thee be bloody-minded;  
Thy name is Gaultier, being rightly sounded.  

**WHITMORE**  
Gaultier or Walter, which it is, I care not:  
Never yet did base dishonour blur our name,  
But with our sword we wiped away the blot;  
Therefore, when merchant-like I sell revenge,  
Broke be my sword, my arms torn and defaced,  
And I proclaim'd a coward through the world!  

**SUFFOLK**  
Stay, Whitmore; for thy prisoner is a prince,  
The Duke of Suffolk, William de la Pole.  

**WHITMORE**  
The Duke of Suffolk muffled up in rags!  

**SUFFOLK**  
Ay, but these rags are no part of the duke:  
Jove sometimes went disguised, and why not I?  

**Captain**  
But Jove was never slain, as thou shalt be.  

**SUFFOLK**  
Obscure and lowly swain, King Henry's blood,  
The honourable blood of Lancaster,  
Must not be shed by such a jaded groom.  
Hast thou not kiss'd thy hand and held my stirrup?  
Bare-headed plodded by my foot-cloth mule  
And thought thee happy when I shook my head?  
How often hast thou waited at my cup,  
Fed from my trencher, kneel'd down at the board.  
When I have feasted with Queen Margaret?  
Remember it and let it make thee crest-fall'n,  
Ay, and allay this thy abortive pride;  
How in our voiding lobby hast thou stood  
And duly waited for my coming forth?  
This hand of mine hath writ in thy behalf,  
And therefore shall it charm thy riotous tongue.  

**WHITMORE**  
Speak, captain, shall I stab the forlorn swain?  

**Captain**  
First let my words stab him, as he hath me.  

**SUFFOLK**  
Base slave, thy words are blunt and so art thou.  

**Captain**  
Convey him hence and on our longboat's side  
Strike off his head.  

**SUFFOLK**  
Thou darest not, for thy own.  

**Captain**  
Yes, Pole.  

**SUFFOLK**  
Pole!  

**Captain**  
Pool! Sir Pool! lord!  
Ay, kennel, puddle, sink; whose filth and dirt  
Troubles the silver spring where England drinks.  
Now will I dam up this thy yawning mouth  
For swallowing the treasure of the realm:  
Thy lips that kiss'd the queen shall sweep the ground;  
And thou that smiledst at good Duke Humphrey's death,  
Against the senseless winds shalt grin in vain,  
Who in contempt shall hiss at thee again:  
And wedded be thou to the hags of hell,  
For daring to affy a mighty lord  
Unto the daughter of a worthless king,  
Having neither subject, wealth, nor diadem.  
By devilish policy art thou grown great,  
And, like ambitious Sylla, overgorged  
With gobbets of thy mother's bleeding heart.  
By thee Anjou and Maine were sold to France,  
The false revolting Normans thorough thee  
Disdain to call us lord, and Picardy  
Hath slain their governors, surprised our forts,  
And sent the ragged soldiers wounded home.  
The princely Warwick, and the Nevils all,  
Whose dreadful swords were never drawn in vain,  
As hating thee, are rising up in arms:  
And now the house of York, thrust from the crown  
By shameful murder of a guiltless king  
And lofty proud encroaching tyranny,  
Burns with revenging fire; whose hopeful colours  
Advance our half-faced sun, striving to shine,  
Under the which is writ 'Invitis nubibus.'  
The commons here in Kent are up in arms:  
And, to conclude, reproach and beggary  
Is crept into the palace of our king.  
And all by thee. Away! convey him hence.  

**SUFFOLK**  
O that I were a god, to shoot forth thunder  
Upon these paltry, servile, abject drudges!  
Small things make base men proud: this villain here,  
Being captain of a pinnace, threatens more  
Than Bargulus the strong Illyrian pirate.  
Drones suck not eagles' blood but rob beehives:  
It is impossible that I should die  
By such a lowly vassal as thyself.  
Thy words move rage and not remorse in me:  
I go of message from the queen to France;  
I charge thee waft me safely cross the Channel.  

**Captain**  
Walter,--  

**WHITMORE**  
Come, Suffolk, I must waft thee to thy death.  

**SUFFOLK**  
Gelidus timor occupat artus it is thee I fear.  

**WHITMORE**  
Thou shalt have cause to fear before I leave thee.  
What, are ye daunted now? now will ye stoop?  

**First Gentleman**  
My gracious lord, entreat him, speak him fair.  

**SUFFOLK**  
Suffolk's imperial tongue is stern and rough,  
Used to command, untaught to plead for favour.  
Far be it we should honour such as these  
With humble suit: no, rather let my head  
Stoop to the block than these knees bow to any  
Save to the God of heaven and to my king;  
And sooner dance upon a bloody pole  
Than stand uncover'd to the vulgar groom.  
True nobility is exempt from fear:  
More can I bear than you dare execute.  

**Captain**  
Hale him away, and let him talk no more.  

**SUFFOLK**  
Come, soldiers, show what cruelty ye can,  
That this my death may never be forgot!  
Great men oft die by vile bezonians:  
A Roman sworder and banditto slave  
Murder'd sweet Tully; Brutus' bastard hand  
Stabb'd Julius Caesar; savage islanders  
Pompey the Great; and Suffolk dies by pirates.  

_Exeunt Whitmore and others with Suffolk_

**Captain**  
And as for these whose ransom we have set,  
It is our pleasure one of them depart;  
Therefore come you with us and let him go.  

_Exeunt all but the First Gentleman_

_Re-enter WHITMORE with SUFFOLK 's body_

**WHITMORE**  
There let his head and lifeless body lie,  
Until the queen his mistress bury it.  

_Exit_

**First Gentleman**  
O barbarous and bloody spectacle!  
His body will I bear unto the king:  
If he revenge it not, yet will his friends;  
So will the queen, that living held him dear.  

_Exit with the body_

### SCENE II. Blackheath.

_Enter GEORGE BEVIS and JOHN HOLLAND_

**BEVIS**  
Come, and get thee a sword, though made of a lath;  
they have been up these two days.  

**HOLLAND**  
They have the more need to sleep now, then.  

**BEVIS**  
I tell thee, Jack Cade the clothier means to dress  
the commonwealth, and turn it, and set a new nap upon it.  

**HOLLAND**  
So he had need, for 'tis threadbare. Well, I say it  
was never merry world in England since gentlemen came up.  

**BEVIS**  
O miserable age! virtue is not regarded in handicrafts-men.  

**HOLLAND**  
The nobility think scorn to go in leather aprons.  

**BEVIS**  
Nay, more, the king's council are no good workmen.  

**HOLLAND**  
True; and yet it is said, labour in thy vocation;  
which is as much to say as, let the magistrates be  
labouring men; and therefore should we be  
magistrates.  

**BEVIS**  
Thou hast hit it; for there's no better sign of a  
brave mind than a hard hand.  

**HOLLAND**  
I see them! I see them! there's Best's son, the  
tanner of Wingham,--  

**BEVIS**  
He shall have the skin of our enemies, to make  
dog's-leather of.  

**HOLLAND**  
And Dick the Butcher,--  

**BEVIS**  
Then is sin struck down like an ox, and iniquity's  
throat cut like a calf.  

**HOLLAND**  
And Smith the weaver,--  

**BEVIS**  
Argo, their thread of life is spun.  

**HOLLAND**  
Come, come, let's fall in with them.  

_Drum. Enter CADE, DICK the Butcher, SMITH the Weaver, and a Sawyer, with
infinite numbers_

**CADE**  
We John Cade, so termed of our supposed father,--  

**DICK**  
_[Aside]_  
Or rather, of stealing a cade of herrings.  

**CADE**  
For our enemies shall fall before us, inspired with  
the spirit of putting down kings and princes,  
\--Command silence.  

**DICK**  
Silence!  

**CADE**  
My father was a Mortimer,--  

**DICK**  
_[Aside]_  
He was an honest man, and a good  
bricklayer.  

**CADE**  
My mother a Plantagenet,--  

**DICK**  
_[Aside]_  
I knew her well; she was a midwife.  

**CADE**  
My wife descended of the Lacies,--  

**DICK**  
_[Aside]_  
She was, indeed, a pedler's daughter, and  
sold many laces.  

**SMITH**  
_[Aside]_  
But now of late, notable to travel with her  
furred pack, she washes bucks here at home.  

**CADE**  
Therefore am I of an honourable house.  

**DICK**  
_[Aside]_  
Ay, by my faith, the field is honourable;  
and there was he borne, under a hedge, for his  
father had never a house but the cage.  

**CADE**  
Valiant I am.  

**SMITH**  
_[Aside]_  
A' must needs; for beggary is valiant.  

**CADE**  
I am able to endure much.  

**DICK**  
_[Aside]_  
No question of that; for I have seen him  
whipped three market-days together.  

**CADE**  
I fear neither sword nor fire.  

**SMITH**  
_[Aside]_  
He need not fear the sword; for his coat is of proof.  

**DICK**  
_[Aside]_  
But methinks he should stand in fear of  
fire, being burnt i' the hand for stealing of sheep.  

**CADE**  
Be brave, then; for your captain is brave, and vows  
reformation. There shall be in England seven  
halfpenny loaves sold for a penny: the three-hooped  
pot; shall have ten hoops and I will make it felony  
to drink small beer: all the realm shall be in  
common; and in Cheapside shall my palfrey go to  
grass: and when I am king, as king I will be,--  

**ALL**  
God save your majesty!  

**CADE**  
I thank you, good people: there shall be no money;  
all shall eat and drink on my score; and I will  
apparel them all in one livery, that they may agree  
like brothers and worship me their lord.  

**DICK**  
The first thing we do, let's kill all the lawyers.  

**CADE**  
Nay, that I mean to do. Is not this a lamentable  
thing, that of the skin of an innocent lamb should  
be made parchment? that parchment, being scribbled  
o'er, should undo a man? Some say the bee stings:  
but I say, 'tis the bee's wax; for I did but seal  
once to a thing, and I was never mine own man  
since. How now! who's there?  

_Enter some, bringing forward the Clerk of Chatham_

**SMITH**  
The clerk of Chatham: he can write and read and  
cast accompt.  

**CADE**  
O monstrous!  

**SMITH**  
We took him setting of boys' copies.  

**CADE**  
Here's a villain!  

**SMITH**  
Has a book in his pocket with red letters in't.  

**CADE**  
Nay, then, he is a conjurer.  

**DICK**  
Nay, he can make obligations, and write court-hand.  

**CADE**  
I am sorry for't: the man is a proper man, of mine  
honour; unless I find him guilty, he shall not die.  
Come hither, sirrah, I must examine thee: what is thy name?  

**Clerk**  
Emmanuel.  

**DICK**  
They use to write it on the top of letters: 'twill  
go hard with you.  

**CADE**  
Let me alone. Dost thou use to write thy name? or  
hast thou a mark to thyself, like an honest  
plain-dealing man?  

**CLERK**  
Sir, I thank God, I have been so well brought up  
that I can write my name.  

**ALL**  
He hath confessed: away with him! he's a villain  
and a traitor.  

**CADE**  
Away with him, I say! hang him with his pen and  
ink-horn about his neck.  

_Exit one with the Clerk_

_Enter MICHAEL_

**MICHAEL**  
Where's our general?  

**CADE**  
Here I am, thou particular fellow.  

**MICHAEL**  
Fly, fly, fly! Sir Humphrey Stafford and his  
brother are hard by, with the king's forces.  

**CADE**  
Stand, villain, stand, or I'll fell thee down. He  
shall be encountered with a man as good as himself:  
he is but a knight, is a'?  

**MICHAEL**  
No.  

**CADE**  
To equal him, I will make myself a knight presently.  

_Kneels_

Rise up Sir John Mortimer.  

_Rises_

Now have at him!  

_Enter SIR HUMPHREY and WILLIAM STAFFORD, with drum and soldiers_

**SIR HUMPHREY**  
Rebellious hinds, the filth and scum of Kent,  
Mark'd for the gallows, lay your weapons down;  
Home to your cottages, forsake this groom:  
The king is merciful, if you revolt.  

**WILLIAM STAFFORD**  
But angry, wrathful, and inclined to blood,  
If you go forward; therefore yield, or die.  

**CADE**  
As for these silken-coated slaves, I pass not:  
It is to you, good people, that I speak,  
Over whom, in time to come, I hope to reign;  
For I am rightful heir unto the crown.  

**SIR HUMPHREY**  
Villain, thy father was a plasterer;  
And thou thyself a shearman, art thou not?  

**CADE**  
And Adam was a gardener.  

**WILLIAM STAFFORD**  
And what of that?  

**CADE**  
Marry, this: Edmund Mortimer, Earl of March.  
Married the Duke of Clarence' daughter, did he not?  

**SIR HUMPHREY**  
Ay, sir.  

**CADE**  
By her he had two children at one birth.  

**WILLIAM STAFFORD**  
That's false.  

**CADE**  
Ay, there's the question; but I say, 'tis true:  
The elder of them, being put to nurse,  
Was by a beggar-woman stolen away;  
And, ignorant of his birth and parentage,  
Became a bricklayer when he came to age:  
His son am I; deny it, if you can.  

**DICK**  
Nay, 'tis too true; therefore he shall be king.  

**SMITH**  
Sir, he made a chimney in my father's house, and  
the bricks are alive at this day to testify it;  
therefore deny it not.  

**SIR HUMPHREY**  
And will you credit this base drudge's words,  
That speaks he knows not what?  

**ALL**  
Ay, marry, will we; therefore get ye gone.  

**WILLIAM STAFFORD**  
Jack Cade, the Duke of York hath taught you this.  

**CADE**  
_[Aside]_  
He lies, for I invented it myself.  
Go to, sirrah, tell the king from me, that, for his  
father's sake, Henry the Fifth, in whose time boys  
went to span-counter for French crowns, I am content  
he shall reign; but I'll be protector over him.  

**DICK**  
And furthermore, well have the Lord Say's head for  
selling the dukedom of Maine.  

**CADE**  
And good reason; for thereby is England mained, and  
fain to go with a staff, but that my puissance holds  
it up. Fellow kings, I tell you that that Lord Say  
hath gelded the commonwealth, and made it an eunuch:  
and more than that, he can speak French; and  
therefore he is a traitor.  

**SIR HUMPHREY**  
O gross and miserable ignorance!  

**CADE**  
Nay, answer, if you can: the Frenchmen are our  
enemies; go to, then, I ask but this: can he that  
speaks with the tongue of an enemy be a good  
counsellor, or no?  

**ALL**  
No, no; and therefore we'll have his head.  

**WILLIAM STAFFORD**  
Well, seeing gentle words will not prevail,  
Assail them with the army of the king.  

**SIR HUMPHREY**  
Herald, away; and throughout every town  
Proclaim them traitors that are up with Cade;  
That those which fly before the battle ends  
May, even in their wives' and children's sight,  
Be hang'd up for example at their doors:  
And you that be the king's friends, follow me.  

_Exeunt WILLIAM STAFFORD and SIR HUMPHREY, and soldiers_

**CADE**  
And you that love the commons, follow me.  
Now show yourselves men; 'tis for liberty.  
We will not leave one lord, one gentleman:  
Spare none but such as go in clouted shoon;  
For they are thrifty honest men, and such  
As would, but that they dare not, take our parts.  

**DICK**  
They are all in order and march toward us.  

**CADE**  
But then are we in order when we are most  
out of order. Come, march forward.  

_Exeunt_

### SCENE III. Another part of Blackheath.

_Alarums to the fight, wherein SIR HUMPHREY and WILLIAM STAFFORD are slain.
Enter CADE and the rest_

**CADE**  
Where's Dick, the butcher of Ashford?  

**DICK**  
Here, sir.  

**CADE**  
They fell before thee like sheep and oxen, and thou  
behavedst thyself as if thou hadst been in thine own  
slaughter-house: therefore thus will I reward thee,  
the Lent shall be as long again as it is; and thou  
shalt have a licence to kill for a hundred lacking  
one.  

**DICK**  
I desire no more.  

**CADE**  
And, to speak truth, thou deservest no less. This  
monument of the victory will I bear;  

_Putting on SIR HUMPHREY 'S brigandine_

and the bodies shall be dragged at my horse' heels  
till I do come to London, where we will have the  
mayor's sword borne before us.  

**DICK**  
If we mean to thrive and do good, break open the  
gaols and let out the prisoners.  

**CADE**  
Fear not that, I warrant thee. Come, let's march  
towards London.  

_Exeunt_

### SCENE IV. London. The palace.

_Enter KING HENRY VI with a supplication, and the QUEEN with SUFFOLK 'S
head, BUCKINGHAM and Lord SAY_

**QUEEN MARGARET**  
Oft have I heard that grief softens the mind,  
And makes it fearful and degenerate;  
Think therefore on revenge and cease to weep.  
But who can cease to weep and look on this?  
Here may his head lie on my throbbing breast:  
But where's the body that I should embrace?  

**BUCKINGHAM**  
What answer makes your grace to the rebels'  
supplication?  

**KING HENRY VI**  
I'll send some holy bishop to entreat;  
For God forbid so many simple souls  
Should perish by the sword! And I myself,  
Rather than bloody war shall cut them short,  
Will parley with Jack Cade their general:  
But stay, I'll read it over once again.  

**QUEEN MARGARET**  
Ah, barbarous villains! hath this lovely face  
Ruled, like a wandering planet, over me,  
And could it not enforce them to relent,  
That were unworthy to behold the same?  

**KING HENRY VI**  
Lord Say, Jack Cade hath sworn to have thy head.  

**SAY**  
Ay, but I hope your highness shall have his.  

**KING HENRY VI**  
How now, madam!  
Still lamenting and mourning for Suffolk's death?  
I fear me, love, if that I had been dead,  
Thou wouldst not have mourn'd so much for me.  

**QUEEN MARGARET**  
No, my love, I should not mourn, but die for thee.  

_Enter a Messenger_

**KING HENRY VI**  
How now! what news? why comest thou in such haste?  

**Messenger**  
The rebels are in Southwark; fly, my lord!  
Jack Cade proclaims himself Lord Mortimer,  
Descended from the Duke of Clarence' house,  
And calls your grace usurper openly  
And vows to crown himself in Westminster.  
His army is a ragged multitude  
Of hinds and peasants, rude and merciless:  
Sir Humphrey Stafford and h is brother's death  
Hath given them heart and courage to proceed:  
All scholars, lawyers, courtiers, gentlemen,  
They call false caterpillars, and intend their death.  

**KING HENRY VI**  
O graceless men! they know not what they do.  

**BUCKINGHAM**  
My gracious lord, return to Killingworth,  
Until a power be raised to put them down.  

**QUEEN MARGARET**  
Ah, were the Duke of Suffolk now alive,  
These Kentish rebels would be soon appeased!  

**KING HENRY VI**  
Lord Say, the traitors hate thee;  
Therefore away with us to Killingworth.  

**SAY**  
So might your grace's person be in danger.  
The sight of me is odious in their eyes;  
And therefore in this city will I stay  
And live alone as secret as I may.  

_Enter another Messenger_

**Messenger**  
Jack Cade hath gotten London bridge:  
The citizens fly and forsake their houses:  
The rascal people, thirsting after prey,  
Join with the traitor, and they jointly swear  
To spoil the city and your royal court.  

**BUCKINGHAM**  
Then linger not, my lord, away, take horse.  

**KING HENRY VI**  
Come, Margaret; God, our hope, will succor us.  

**QUEEN MARGARET**  
My hope is gone, now Suffolk is deceased.  

**KING HENRY VI**  
Farewell, my lord: trust not the Kentish rebels.  

**BUCKINGHAM**  
Trust nobody, for fear you be betray'd.  

**SAY**  
The trust I have is in mine innocence,  
And therefore am I bold and resolute.  

_Exeunt_

### SCENE V. London. The Tower.

_Enter SCALES upon the Tower, walking. Then enter two or three Citizens
below_

**SCALES**  
How now! is Jack Cade slain?  

**First Citizen**  
No, my lord, nor likely to be slain; for they have  
won the bridge, killing all those that withstand  
them: the lord mayor craves aid of your honour from  
the Tower, to defend the city from the rebels.  

**SCALES**  
Such aid as I can spare you shall command;  
But I am troubled here with them myself;  
The rebels have assay'd to win the Tower.  
But get you to Smithfield, and gather head,  
And thither I will send you Matthew Goffe;  
Fight for your king, your country and your lives;  
And so, farewell, for I must hence again.  

_Exeunt_

### SCENE VI. London. Cannon Street.

_Enter CADE and the rest, and strikes his staff on London-stone_

**CADE**  
Now is Mortimer lord of this city. And here, sitting  
upon London-stone, I charge and command that, of the  
city's cost, the pissing-conduit run nothing but  
claret wine this first year of our reign. And now  
henceforward it shall be treason for any that calls  
me other than Lord Mortimer.  

_Enter a Soldier, running_

**Soldier**  
Jack Cade! Jack Cade!  

**CADE**  
Knock him down there.  

_They kill him_

**SMITH**  
If this fellow be wise, he'll never call ye Jack  
Cade more: I think he hath a very fair warning.  

**DICK**  
My lord, there's an army gathered together in  
Smithfield.  

**CADE**  
Come, then, let's go fight with them; but first, go  
and set London bridge on fire; and, if you can, burn  
down the Tower too. Come, let's away.  

_Exeunt_

### SCENE VII. London. Smithfield.

_Alarums. MATTHEW GOFFE is slain, and all the rest. Then enter CADE, with
his company._

**CADE**  
So, sirs: now go some and pull down the Savoy;  
others to the inns of court; down with them all.  

**DICK**  
I have a suit unto your lordship.  

**CADE**  
Be it a lordship, thou shalt have it for that word.  

**DICK**  
Only that the laws of England may come out of your mouth.  

**HOLLAND**  
_[Aside]_  
Mass, 'twill be sore law, then; for he was  
thrust in the mouth with a spear, and 'tis not whole  
yet.  

**SMITH**  
_[Aside]_  
Nay, John, it will be stinking law for his  
breath stinks with eating toasted cheese.  

**CADE**  
I have thought upon it, it shall be so. Away, burn  
all the records of the realm: my mouth shall be  
the parliament of England.  

**HOLLAND**  
_[Aside]_  
Then we are like to have biting statutes,  
unless his teeth be pulled out.  

**CADE**  
And henceforward all things shall be in common.  

_Enter a Messenger_

**Messenger**  
My lord, a prize, a prize! here's the Lord Say,  
which sold the towns in France; he that made us pay  
one and twenty fifteens, and one shilling to the  
pound, the last subsidy.  

_Enter BEVIS, with Lord SAY_

**CADE**  
Well, he shall be beheaded for it ten times. Ah,  
thou say, thou serge, nay, thou buckram lord! now  
art thou within point-blank of our jurisdiction  
regal. What canst thou answer to my majesty for  
giving up of Normandy unto Mounsieur Basimecu, the  
dauphin of France? Be it known unto thee by these  
presence, even the presence of Lord Mortimer, that I  
am the besom that must sweep the court clean of such  
filth as thou art. Thou hast most traitorously  
corrupted the youth of the realm in erecting a  
grammar school; and whereas, before, our forefathers  
had no other books but the score and the tally, thou  
hast caused printing to be used, and, contrary to  
the king, his crown and dignity, thou hast built a  
paper-mill. It will be proved to thy face that thou  
hast men about thee that usually talk of a noun and  
a verb, and such abominable words as no Christian  
ear can endure to hear. Thou hast appointed  
justices of peace, to call poor men before them  
about matters they were not able to answer.  
Moreover, thou hast put them in prison; and because  
they could not read, thou hast hanged them; when,  
indeed, only for that cause they have been most  
worthy to live. Thou dost ride in a foot-cloth, dost thou not?  

**SAY**  
What of that?  

**CADE**  
Marry, thou oughtest not to let thy horse wear a  
cloak, when honester men than thou go in their hose  
and doublets.  

**DICK**  
And work in their shirt too; as myself, for example,  
that am a butcher.  

**SAY**  
You men of Kent,--  

**DICK**  
What say you of Kent?  

**SAY**  
Nothing but this; 'tis 'bona terra, mala gens.'  

**CADE**  
Away with him, away with him! he speaks Latin.  

**SAY**  
Hear me but speak, and bear me where you will.  
Kent, in the Commentaries Caesar writ,  
Is term'd the civil'st place of this isle:  
Sweet is the country, because full of riches;  
The people liberal, valiant, active, wealthy;  
Which makes me hope you are not void of pity.  
I sold not Maine, I lost not Normandy,  
Yet, to recover them, would lose my life.  
Justice with favour have I always done;  
Prayers and tears have moved me, gifts could never.  
When have I aught exacted at your hands,  
But to maintain the king, the realm and you?  
Large gifts have I bestow'd on learned clerks,  
Because my book preferr'd me to the king,  
And seeing ignorance is the curse of God,  
Knowledge the wing wherewith we fly to heaven,  
Unless you be possess'd with devilish spirits,  
You cannot but forbear to murder me:  
This tongue hath parley'd unto foreign kings  
For your behoof,--  

**CADE**  
Tut, when struck'st thou one blow in the field?  

**SAY**  
Great men have reaching hands: oft have I struck  
Those that I never saw and struck them dead.  

**BEVIS**  
O monstrous coward! what, to come behind folks?  

**SAY**  
These cheeks are pale for watching for your good.  

**CADE**  
Give him a box o' the ear and that will make 'em red again.  

**SAY**  
Long sitting to determine poor men's causes  
Hath made me full of sickness and diseases.  

**CADE**  
Ye shall have a hempen caudle, then, and the help of hatchet.  

**DICK**  
Why dost thou quiver, man?  

**SAY**  
The palsy, and not fear, provokes me.  

**CADE**  
Nay, he nods at us, as who should say, I'll be even  
with you: I'll see if his head will stand steadier  
on a pole, or no. Take him away, and behead him.  

**SAY**  
Tell me wherein have I offended most?  
Have I affected wealth or honour? speak.  
Are my chests fill'd up with extorted gold?  
Is my apparel sumptuous to behold?  
Whom have I injured, that ye seek my death?  
These hands are free from guiltless bloodshedding,  
This breast from harbouring foul deceitful thoughts.  
O, let me live!  

**CADE**  
_[Aside]_  
I feel remorse in myself with his words;  
but I'll bridle it: he shall die, an it be but for  
pleading so well for his life. Away with him! he  
has a familiar under his tongue; he speaks not o'  
God's name. Go, take him away, I say, and strike  
off his head presently; and then break into his  
son-in-law's house, Sir James Cromer, and strike off  
his head, and bring them both upon two poles hither.  

**ALL**  
It shall be done.  

**SAY**  
Ah, countrymen! if when you make your prayers,  
God should be so obdurate as yourselves,  
How would it fare with your departed souls?  
And therefore yet relent, and save my life.  

**CADE**  
Away with him! and do as I command ye.  

_Exeunt some with Lord SAY_

The proudest peer in the realm shall not wear a head  
on his shoulders, unless he pay me tribute; there  
shall not a maid be married, but she shall pay to me  
her maidenhead ere they have it: men shall hold of  
me in capite; and we charge and command that their  
wives be as free as heart can wish or tongue can tell.  

**DICK**  
My lord, when shall we go to Cheapside and take up  
commodities upon our bills?  

**CADE**  
Marry, presently.  

**ALL**  
O, brave!  

_Re-enter one with the heads_

**CADE**  
But is not this braver? Let them kiss one another,  
for they loved well when they were alive. Now part  
them again, lest they consult about the giving up of  
some more towns in France. Soldiers, defer the  
spoil of the city until night: for with these borne  
before us, instead of maces, will we ride through  
the streets, and at every corner have them kiss. Away!  

_Exeunt_

### SCENE VIII. Southwark.

_Alarum and retreat. Enter CADE and all his rabblement_

**CADE**  
Up Fish Street! down Saint Magnus' Corner! Kill  
and knock down! throw them into Thames!  

_Sound a parley_

What noise is this I hear? Dare any be so bold to  
sound retreat or parley, when I command them kill?  

_Enter BUCKINGHAM and CLIFFORD, attended_

**BUCKINGHAM**  
Ay, here they be that dare and will disturb thee:  
Know, Cade, we come ambassadors from the king  
Unto the commons whom thou hast misled;  
And here pronounce free pardon to them all  
That will forsake thee and go home in peace.  

**CLIFFORD**  
What say ye, countrymen? will ye relent,  
And yield to mercy whilst 'tis offer'd you;  
Or let a rebel lead you to your deaths?  
Who loves the king and will embrace his pardon,  
Fling up his cap, and say 'God save his majesty!'  
Who hateth him and honours not his father,  
Henry the Fifth, that made all France to quake,  
Shake he his weapon at us and pass by.  

**ALL**  
God save the king! God save the king!  

**CADE**  
What, Buckingham and Clifford, are ye so brave? And  
you, base peasants, do ye believe him? will you  
needs be hanged with your pardons about your necks?  
Hath my sword therefore broke through London gates,  
that you should leave me at the White Hart in  
Southwark? I thought ye would never have given out  
these arms till you had recovered your ancient  
freedom: but you are all recreants and dastards,  
and delight to live in slavery to the nobility. Let  
them break your backs with burthens, take your  
houses over your heads, ravish your wives and  
daughters before your faces: for me, I will make  
shift for one; and so, God's curse light upon you  
all!  

**ALL**  
We'll follow Cade, we'll follow Cade!  

**CLIFFORD**  
Is Cade the son of Henry the Fifth,  
That thus you do exclaim you'll go with him?  
Will he conduct you through the heart of France,  
And make the meanest of you earls and dukes?  
Alas, he hath no home, no place to fly to;  
Nor knows he how to live but by the spoil,  
Unless by robbing of your friends and us.  
Were't not a shame, that whilst you live at jar,  
The fearful French, whom you late vanquished,  
Should make a start o'er seas and vanquish you?  
Methinks already in this civil broil  
I see them lording it in London streets,  
Crying 'Villiago!' unto all they meet.  
Better ten thousand base-born Cades miscarry  
Than you should stoop unto a Frenchman's mercy.  
To France, to France, and get what you have lost;  
Spare England, for it is your native coast;  
Henry hath money, you are strong and manly;  
God on our side, doubt not of victory.  

**ALL**  
A Clifford! a Clifford! we'll follow the king and Clifford.  

**CADE**  
Was ever feather so lightly blown to and fro as this  
multitude? The name of Henry the Fifth hales them  
to an hundred mischiefs, and makes them leave me  
desolate. I see them lay their heads together to  
surprise me. My sword make way for me, for here is  
no staying. In despite of the devils and hell, have  
through the very middest of you? and heavens and  
honour be witness, that no want of resolution in me.  
but only my followers' base and ignominious  
treasons, makes me betake me to my heels.  

_Exit_

**BUCKINGHAM**  
What, is he fled? Go some, and follow him;  
And he that brings his head unto the king  
Shall have a thousand crowns for his reward.  

_Exeunt some of them_

Follow me, soldiers: we'll devise a mean  
To reconcile you all unto the king.  

_Exeunt_

### SCENE IX. Kenilworth Castle.

_Sound Trumpets. Enter KING HENRY VI, QUEEN MARGARET, and SOMERSET, on the
terrace_

**KING HENRY VI**  
Was ever king that joy'd an earthly throne,  
And could command no more content than I?  
No sooner was I crept out of my cradle  
But I was made a king, at nine months old.  
Was never subject long'd to be a king  
As I do long and wish to be a subject.  

_Enter BUCKINGHAM and CLIFFORD_

**BUCKINGHAM**  
Health and glad tidings to your majesty!  

**KING HENRY VI**  
Why, Buckingham, is the traitor Cade surprised?  
Or is he but retired to make him strong?  

_Enter below, multitudes, with halters about their necks_

**CLIFFORD**  
He is fled, my lord, and all his powers do yield;  
And humbly thus, with halters on their necks,  
Expect your highness' doom of life or death.  

**KING HENRY VI**  
Then, heaven, set ope thy everlasting gates,  
To entertain my vows of thanks and praise!  
Soldiers, this day have you redeemed your lives,  
And show'd how well you love your prince and country:  
Continue still in this so good a mind,  
And Henry, though he be infortunate,  
Assure yourselves, will never be unkind:  
And so, with thanks and pardon to you all,  
I do dismiss you to your several countries.  

**ALL**  
God save the king! God save the king!  

_Enter a Messenger_

**Messenger**  
Please it your grace to be advertised  
The Duke of York is newly come from Ireland,  
And with a puissant and a mighty power  
Of gallowglasses and stout kerns  
Is marching hitherward in proud array,  
And still proclaimeth, as he comes along,  
His arms are only to remove from thee  
The Duke of Somerset, whom he terms traitor.  

**KING HENRY VI**  
Thus stands my state, 'twixt Cade and York distress'd.  
Like to a ship that, having 'scaped a tempest,  
Is straightway calm'd and boarded with a pirate:  
But now is Cade driven back, his men dispersed;  
And now is York in arms to second him.  
I pray thee, Buckingham, go and meet him,  
And ask him what's the reason of these arms.  
Tell him I'll send Duke Edmund to the Tower;  
And, Somerset, we'll commit thee thither,  
Until his army be dismiss'd from him.  

**SOMERSET**  
My lord,  
I'll yield myself to prison willingly,  
Or unto death, to do my country good.  

**KING HENRY VI**  
In any case, be not too rough in terms;  
For he is fierce and cannot brook hard language.  

**BUCKINGHAM**  
I will, my lord; and doubt not so to deal  
As all things shall redound unto your good.  

**KING HENRY VI**  
Come, wife, let's in, and learn to govern better;  
For yet may England curse my wretched reign.  

_Flourish. Exeunt_

### SCENE X. Kent. IDEN's garden.

_Enter CADE_

**CADE**  
Fie on ambition! fie on myself, that have a sword,  
and yet am ready to famish! These five days have I  
hid me in these woods and durst not peep out, for  
all the country is laid for me; but now am I so  
hungry that if I might have a lease of my life for a  
thousand years I could stay no longer. Wherefore,  
on a brick wall have I climbed into this garden, to  
see if I can eat grass, or pick a sallet another  
while, which is not amiss to cool a man's stomach  
this hot weather. And I think this word 'sallet'  
was born to do me good: for many a time, but for a  
sallet, my brainpan had been cleft with a brown  
bill; and many a time, when I have been dry and  
bravely marching, it hath served me instead of a  
quart pot to drink in; and now the word 'sallet'  
must serve me to feed on.  

_Enter IDEN_

**IDEN**  
Lord, who would live turmoiled in the court,  
And may enjoy such quiet walks as these?  
This small inheritance my father left me  
Contenteth me, and worth a monarchy.  
I seek not to wax great by others' waning,  
Or gather wealth, I care not, with what envy:  
Sufficeth that I have maintains my state  
And sends the poor well pleased from my gate.  

**CADE**  
Here's the lord of the soil come to seize me for a  
stray, for entering his fee-simple without leave.  
Ah, villain, thou wilt betray me, and get a thousand  
crowns of the king carrying my head to him: but  
I'll make thee eat iron like an ostrich, and swallow  
my sword like a great pin, ere thou and I part.  

**IDEN**  
Why, rude companion, whatsoe'er thou be,  
I know thee not; why, then, should I betray thee?  
Is't not enough to break into my garden,  
And, like a thief, to come to rob my grounds,  
Climbing my walls in spite of me the owner,  
But thou wilt brave me with these saucy terms?  

**CADE**  
Brave thee! ay, by the best blood that ever was  
broached, and beard thee too. Look on me well: I  
have eat no meat these five days; yet, come thou and  
thy five men, and if I do not leave you all as dead  
as a doornail, I pray God I may never eat grass more.  

**IDEN**  
Nay, it shall ne'er be said, while England stands,  
That Alexander Iden, an esquire of Kent,  
Took odds to combat a poor famish'd man.  
Oppose thy steadfast-gazing eyes to mine,  
See if thou canst outface me with thy looks:  
Set limb to limb, and thou art far the lesser;  
Thy hand is but a finger to my fist,  
Thy leg a stick compared with this truncheon;  
My foot shall fight with all the strength thou hast;  
And if mine arm be heaved in the air,  
Thy grave is digg'd already in the earth.  
As for words, whose greatness answers words,  
Let this my sword report what speech forbears.  

**CADE**  
By my valour, the most complete champion that ever I  
heard! Steel, if thou turn the edge, or cut not out  
the burly-boned clown in chines of beef ere thou  
sleep in thy sheath, I beseech God on my knees thou  
mayst be turned to hobnails.  

_Here they fight. CADE falls_

O, I am slain! famine and no other hath slain me:  
let ten thousand devils come against me, and give me  
but the ten meals I have lost, and I'll defy them  
all. Wither, garden; and be henceforth a  
burying-place to all that do dwell in this house,  
because the unconquered soul of Cade is fled.  

**IDEN**  
Is't Cade that I have slain, that monstrous traitor?  
Sword, I will hollow thee for this thy deed,  
And hang thee o'er my tomb when I am dead:  
Ne'er shall this blood be wiped from thy point;  
But thou shalt wear it as a herald's coat,  
To emblaze the honour that thy master got.  

**CADE**  
Iden, farewell, and be proud of thy victory. Tell  
Kent from me, she hath lost her best man, and exhort  
all the world to be cowards; for I, that never  
feared any, am vanquished by famine, not by valour.  

_Dies_

**IDEN**  
How much thou wrong'st me, heaven be my judge.  
Die, damned wretch, the curse of her that bare thee;  
And as I thrust thy body in with my sword,  
So wish I, I might thrust thy soul to hell.  
Hence will I drag thee headlong by the heels  
Unto a dunghill which shall be thy grave,  
And there cut off thy most ungracious head;  
Which I will bear in triumph to the king,  
Leaving thy trunk for crows to feed upon.  

_Exit_

# ACT V

### SCENE I. Fields between Dartford and Blackheath.

_Enter YORK, and his army of Irish, with drum and colours_

**YORK**  
From Ireland thus comes York to claim his right,  
And pluck the crown from feeble Henry's head:  
Ring, bells, aloud; burn, bonfires, clear and bright,  
To entertain great England's lawful king.  
Ah! sancta majestas, who would not buy thee dear?  
Let them obey that know not how to rule;  
This hand was made to handle naught but gold.  
I cannot give due action to my words,  
Except a sword or sceptre balance it:  
A sceptre shall it have, have I a soul,  
On which I'll toss the flower-de-luce of France.  

_Enter BUCKINGHAM_

Whom have we here? Buckingham, to disturb me?  
The king hath sent him, sure: I must dissemble.  

**BUCKINGHAM**  
York, if thou meanest well, I greet thee well.  

**YORK**  
Humphrey of Buckingham, I accept thy greeting.  
Art thou a messenger, or come of pleasure?  

**BUCKINGHAM**  
A messenger from Henry, our dread liege,  
To know the reason of these arms in peace;  
Or why thou, being a subject as I am,  
Against thy oath and true allegiance sworn,  
Should raise so great a power without his leave,  
Or dare to bring thy force so near the court.  

**YORK**  
_[Aside]_  
Scarce can I speak, my choler is so great:  
O, I could hew up rocks and fight with flint,  
I am so angry at these abject terms;  
And now, like Ajax Telamonius,  
On sheep or oxen could I spend my fury.  
I am far better born than is the king,  
More like a king, more kingly in my thoughts:  
But I must make fair weather yet a while,  
Till Henry be more weak and I more strong,--  
Buckingham, I prithee, pardon me,  
That I have given no answer all this while;  
My mind was troubled with deep melancholy.  
The cause why I have brought this army hither  
Is to remove proud Somerset from the king,  
Seditious to his grace and to the state.  

**BUCKINGHAM**  
That is too much presumption on thy part:  
But if thy arms be to no other end,  
The king hath yielded unto thy demand:  
The Duke of Somerset is in the Tower.  

**YORK**  
Upon thine honour, is he prisoner?  

**BUCKINGHAM**  
Upon mine honour, he is prisoner.  

**YORK**  
Then, Buckingham, I do dismiss my powers.  
Soldiers, I thank you all; disperse yourselves;  
Meet me to-morrow in St. George's field,  
You shall have pay and every thing you wish.  
And let my sovereign, virtuous Henry,  
Command my eldest son, nay, all my sons,  
As pledges of my fealty and love;  
I'll send them all as willing as I live:  
Lands, goods, horse, armour, any thing I have,  
Is his to use, so Somerset may die.  

**BUCKINGHAM**  
York, I commend this kind submission:  
We twain will go into his highness' tent.  

_Enter KING HENRY VI and Attendants_

**KING HENRY VI**  
Buckingham, doth York intend no harm to us,  
That thus he marcheth with thee arm in arm?  

**YORK**  
In all submission and humility  
York doth present himself unto your highness.  

**KING HENRY VI**  
Then what intends these forces thou dost bring?  

**YORK**  
To heave the traitor Somerset from hence,  
And fight against that monstrous rebel Cade,  
Who since I heard to be discomfited.  

_Enter IDEN, with CADE 'S head_

**IDEN**  
If one so rude and of so mean condition  
May pass into the presence of a king,  
Lo, I present your grace a traitor's head,  
The head of Cade, whom I in combat slew.  

**KING HENRY VI**  
The head of Cade! Great God, how just art Thou!  
O, let me view his visage, being dead,  
That living wrought me such exceeding trouble.  
Tell me, my friend, art thou the man that slew him?  

**IDEN**  
I was, an't like your majesty.  

**KING HENRY VI**  
How art thou call'd? and what is thy degree?  

**IDEN**  
Alexander Iden, that's my name;  
A poor esquire of Kent, that loves his king.  

**BUCKINGHAM**  
So please it you, my lord, 'twere not amiss  
He were created knight for his good service.  

**KING HENRY VI**  
Iden, kneel down.  

_He kneels_

Rise up a knight.  
We give thee for reward a thousand marks,  
And will that thou henceforth attend on us.  

**IDEN**  
May Iden live to merit such a bounty.  
And never live but true unto his liege!  

_Rises_

_Enter QUEEN MARGARET and SOMERSET_

**KING HENRY VI**  
See, Buckingham, Somerset comes with the queen:  
Go, bid her hide him quickly from the duke.  

**QUEEN MARGARET**  
For thousand Yorks he shall not hide his head,  
But boldly stand and front him to his face.  

**YORK**  
How now! is Somerset at liberty?  
Then, York, unloose thy long-imprison'd thoughts,  
And let thy tongue be equal with thy heart.  
Shall I endure the sight of Somerset?  
False king! why hast thou broken faith with me,  
Knowing how hardly I can brook abuse?  
King did I call thee? no, thou art not king,  
Not fit to govern and rule multitudes,  
Which darest not, no, nor canst not rule a traitor.  
That head of thine doth not become a crown;  
Thy hand is made to grasp a palmer's staff,  
And not to grace an awful princely sceptre.  
That gold must round engirt these brows of mine,  
Whose smile and frown, like to Achilles' spear,  
Is able with the change to kill and cure.  
Here is a hand to hold a sceptre up  
And with the same to act controlling laws.  
Give place: by heaven, thou shalt rule no more  
O'er him whom heaven created for thy ruler.  

**SOMERSET**  
O monstrous traitor! I arrest thee, York,  
Of capital treason 'gainst the king and crown;  
Obey, audacious traitor; kneel for grace.  

**YORK**  
Wouldst have me kneel? first let me ask of these,  
If they can brook I bow a knee to man.  
Sirrah, call in my sons to be my bail;  

_Exit Attendant_

I know, ere they will have me go to ward,  
They'll pawn their swords for my enfranchisement.  

**QUEEN MARGARET**  
Call hither Clifford! bid him come amain,  
To say if that the bastard boys of York  
Shall be the surety for their traitor father.  

_Exit BUCKINGHAM_

**YORK**  
O blood-besotted Neapolitan,  
Outcast of Naples, England's bloody scourge!  
The sons of York, thy betters in their birth,  
Shall be their father's bail; and bane to those  
That for my surety will refuse the boys!  

_Enter EDWARD and RICHARD_

See where they come: I'll warrant they'll  
make it good.  

_Enter CLIFFORD and YOUNG CLIFFORD_

**QUEEN MARGARET**  
And here comes Clifford to deny their bail.  

**CLIFFORD**  
Health and all happiness to my lord the king!  

_Kneels_

**YORK**  
I thank thee, Clifford: say, what news with thee?  
Nay, do not fright us with an angry look;  
We are thy sovereign, Clifford, kneel again;  
For thy mistaking so, we pardon thee.  

**CLIFFORD**  
This is my king, York, I do not mistake;  
But thou mistakest me much to think I do:  
To Bedlam with him! is the man grown mad?  

**KING HENRY VI**  
Ay, Clifford; a bedlam and ambitious humour  
Makes him oppose himself against his king.  

**CLIFFORD**  
He is a traitor; let him to the Tower,  
And chop away that factious pate of his.  

**QUEEN MARGARET**  
He is arrested, but will not obey;  
His sons, he says, shall give their words for him.  

**YORK**  
Will you not, sons?  

**EDWARD**  
Ay, noble father, if our words will serve.  

**RICHARD**  
And if words will not, then our weapons shall.  

**CLIFFORD**  
Why, what a brood of traitors have we here!  

**YORK**  
Look in a glass, and call thy image so:  
I am thy king, and thou a false-heart traitor.  
Call hither to the stake my two brave bears,  
That with the very shaking of their chains  
They may astonish these fell-lurking curs:  
Bid Salisbury and Warwick come to me.  

_Enter the WARWICK and SALISBURY_

**CLIFFORD**  
Are these thy bears? we'll bait thy bears to death.  
And manacle the bear-ward in their chains,  
If thou darest bring them to the baiting place.  

**RICHARD**  
Oft have I seen a hot o'erweening cur  
Run back and bite, because he was withheld;  
Who, being suffer'd with the bear's fell paw,  
Hath clapp'd his tail between his legs and cried:  
And such a piece of service will you do,  
If you oppose yourselves to match Lord Warwick.  

**CLIFFORD**  
Hence, heap of wrath, foul indigested lump,  
As crooked in thy manners as thy shape!  

**YORK**  
Nay, we shall heat you thoroughly anon.  

**CLIFFORD**  
Take heed, lest by your heat you burn yourselves.  

**KING HENRY VI**  
Why, Warwick, hath thy knee forgot to bow?  
Old Salisbury, shame to thy silver hair,  
Thou mad misleader of thy brain-sick son!  
What, wilt thou on thy death-bed play the ruffian,  
And seek for sorrow with thy spectacles?  
O, where is faith? O, where is loyalty?  
If it be banish'd from the frosty head,  
Where shall it find a harbour in the earth?  
Wilt thou go dig a grave to find out war,  
And shame thine honourable age with blood?  
Why art thou old, and want'st experience?  
Or wherefore dost abuse it, if thou hast it?  
For shame! in duty bend thy knee to me  
That bows unto the grave with mickle age.  

**SALISBURY**  
My lord, I have consider'd with myself  
The title of this most renowned duke;  
And in my conscience do repute his grace  
The rightful heir to England's royal seat.  

**KING HENRY VI**  
Hast thou not sworn allegiance unto me?  

**SALISBURY**  
I have.  

**KING HENRY VI**  
Canst thou dispense with heaven for such an oath?  

**SALISBURY**  
It is great sin to swear unto a sin,  
But greater sin to keep a sinful oath.  
Who can be bound by any solemn vow  
To do a murderous deed, to rob a man,  
To force a spotless virgin's chastity,  
To reave the orphan of his patrimony,  
To wring the widow from her custom'd right,  
And have no other reason for this wrong  
But that he was bound by a solemn oath?  

**QUEEN MARGARET**  
A subtle traitor needs no sophister.  

**KING HENRY VI**  
Call Buckingham, and bid him arm himself.  

**YORK**  
Call Buckingham, and all the friends thou hast,  
I am resolved for death or dignity.  

**CLIFFORD**  
The first I warrant thee, if dreams prove true.  

**WARWICK**  
You were best to go to bed and dream again,  
To keep thee from the tempest of the field.  

**CLIFFORD**  
I am resolved to bear a greater storm  
Than any thou canst conjure up to-day;  
And that I'll write upon thy burgonet,  
Might I but know thee by thy household badge.  

**WARWICK**  
Now, by my father's badge, old Nevil's crest,  
The rampant bear chain'd to the ragged staff,  
This day I'll wear aloft my burgonet,  
As on a mountain top the cedar shows  
That keeps his leaves in spite of any storm,  
Even to affright thee with the view thereof.  

**CLIFFORD**  
And from thy burgonet I'll rend thy bear  
And tread it under foot with all contempt,  
Despite the bear-ward that protects the bear.  

**YOUNG CLIFFORD**  
And so to arms, victorious father,  
To quell the rebels and their complices.  

**RICHARD**  
Fie! charity, for shame! speak not in spite,  
For you shall sup with Jesu Christ to-night.  

**YOUNG CLIFFORD**  
Foul stigmatic, that's more than thou canst tell.  

**RICHARD**  
If not in heaven, you'll surely sup in hell.  

_Exeunt severally_

### SCENE II. Saint Alban's.

_Alarums to the battle. Enter WARWICK_

**WARWICK**  
Clifford of Cumberland, 'tis Warwick calls:  
And if thou dost not hide thee from the bear,  
Now, when the angry trumpet sounds alarum  
And dead men's cries do fill the empty air,  
Clifford, I say, come forth and fight with me:  
Proud northern lord, Clifford of Cumberland,  
Warwick is hoarse with calling thee to arms.  

_Enter YORK_

How now, my noble lord? what, all afoot?  

**YORK**  
The deadly-handed Clifford slew my steed,  
But match to match I have encounter'd him  
And made a prey for carrion kites and crows  
Even of the bonny beast he loved so well.  

_Enter CLIFFORD_

**WARWICK**  
Of one or both of us the time is come.  

**YORK**  
Hold, Warwick, seek thee out some other chase,  
For I myself must hunt this deer to death.  

**WARWICK**  
Then, nobly, York; 'tis for a crown thou fight'st.  
As I intend, Clifford, to thrive to-day,  
It grieves my soul to leave thee unassail'd.  

_Exit_

**CLIFFORD**  
What seest thou in me, York? why dost thou pause?  

**YORK**  
With thy brave bearing should I be in love,  
But that thou art so fast mine enemy.  

**CLIFFORD**  
Nor should thy prowess want praise and esteem,  
But that 'tis shown ignobly and in treason.  

**YORK**  
So let it help me now against thy sword  
As I in justice and true right express it.  

**CLIFFORD**  
My soul and body on the action both!  

**YORK**  
A dreadful lay! Address thee instantly.  

_They fight, and CLIFFORD falls_

**CLIFFORD**  
La fin couronne les oeuvres.  

_Dies_

**YORK**  
Thus war hath given thee peace, for thou art still.  
Peace with his soul, heaven, if it be thy will!  

_Exit_

_Enter YOUNG CLIFFORD_

**YOUNG CLIFFORD**  
Shame and confusion! all is on the rout;  
Fear frames disorder, and disorder wounds  
Where it should guard. O war, thou son of hell,  
Whom angry heavens do make their minister  
Throw in the frozen bosoms of our part  
Hot coals of vengeance! Let no soldier fly.  
He that is truly dedicate to war  
Hath no self-love, nor he that loves himself  
Hath not essentially but by circumstance  
The name of valour.  

_Seeing his dead father_

O, let the vile world end,  
And the premised flames of the last day  
Knit earth and heaven together!  
Now let the general trumpet blow his blast,  
Particularities and petty sounds  
To cease! Wast thou ordain'd, dear father,  
To lose thy youth in peace, and to achieve  
The silver livery of advised age,  
And, in thy reverence and thy chair-days, thus  
To die in ruffian battle? Even at this sight  
My heart is turn'd to stone: and while 'tis mine,  
It shall be stony. York not our old men spares;  
No more will I their babes: tears virginal  
Shall be to me even as the dew to fire,  
And beauty that the tyrant oft reclaims  
Shall to my flaming wrath be oil and flax.  
Henceforth I will not have to do with pity:  
Meet I an infant of the house of York,  
Into as many gobbets will I cut it  
As wild Medea young Absyrtus did:  
In cruelty will I seek out my fame.  
Come, thou new ruin of old Clifford's house:  
As did AEneas old Anchises bear,  
So bear I thee upon my manly shoulders;  
But then AEneas bare a living load,  
Nothing so heavy as these woes of mine.  

_Exit, bearing off his father_

_Enter RICHARD and SOMERSET to fight. SOMERSET is killed_

**RICHARD**  
So, lie thou there;  
For underneath an alehouse' paltry sign,  
The Castle in Saint Alban's, Somerset  
Hath made the wizard famous in his death.  
Sword, hold thy temper; heart, be wrathful still:  
Priests pray for enemies, but princes kill.  

_Exit_

_Fight: excursions. Enter KING HENRY VI, QUEEN MARGARET, and others_

**QUEEN MARGARET**  
Away, my lord! you are slow; for shame, away!  

**KING HENRY VI**  
Can we outrun the heavens? good Margaret, stay.  

**QUEEN MARGARET**  
What are you made of? you'll nor fight nor fly:  
Now is it manhood, wisdom and defence,  
To give the enemy way, and to secure us  
By what we can, which can no more but fly.  

_Alarum afar off_

If you be ta'en, we then should see the bottom  
Of all our fortunes: but if we haply scape,  
As well we may, if not through your neglect,  
We shall to London get, where you are loved  
And where this breach now in our fortunes made  
May readily be stopp'd.  

_Re-enter YOUNG CLIFFORD_

**YOUNG CLIFFORD**  
But that my heart's on future mischief set,  
I would speak blasphemy ere bid you fly:  
But fly you must; uncurable discomfit  
Reigns in the hearts of all our present parts.  
Away, for your relief! and we will live  
To see their day and them our fortune give:  
Away, my lord, away!  

_Exeunt_

### SCENE III. Fields near St. Alban's.

_Alarum. Retreat. Enter YORK, RICHARD, WARWICK, and Soldiers, with drum and
colours_

**YORK**  
Of Salisbury, who can report of him,  
That winter lion, who in rage forgets  
Aged contusions and all brush of time,  
And, like a gallant in the brow of youth,  
Repairs him with occasion? This happy day  
Is not itself, nor have we won one foot,  
If Salisbury be lost.  

**RICHARD**  
My noble father,  
Three times to-day I holp him to his horse,  
Three times bestrid him; thrice I led him off,  
Persuaded him from any further act:  
But still, where danger was, still there I met him;  
And like rich hangings in a homely house,  
So was his will in his old feeble body.  
But, noble as he is, look where he comes.  

_Enter SALISBURY_

**SALISBURY**  
Now, by my sword, well hast thou fought to-day;  
By the mass, so did we all. I thank you, Richard:  
God knows how long it is I have to live;  
And it hath pleased him that three times to-day  
You have defended me from imminent death.  
Well, lords, we have not got that which we have:  
'Tis not enough our foes are this time fled,  
Being opposites of such repairing nature.  

**YORK**  
I know our safety is to follow them;  
For, as I hear, the king is fled to London,  
To call a present court of parliament.  
Let us pursue him ere the writs go forth.  
What says Lord Warwick? shall we after them?  

**WARWICK**  
After them! nay, before them, if we can.  
Now, by my faith, lords, 'twas a glorious day:  
Saint Alban's battle won by famous York  
Shall be eternized in all age to come.  
Sound drums and trumpets, and to London all:  
And more such days as these to us befall!  

_Exeunt_
